<?php
/**
 * The Sticky template for displaying sticky posts
 *
 * Used for index/archive
 *
 * @package WordPress
 * @subpackage PRESTON
 * @since PRESTON 1.0
 */

$preston_columns = max(1, min(3, count(get_option( 'sticky_posts' ))));
$preston_post_format = get_post_format();
$preston_post_format = empty($preston_post_format) ? 'standard' : str_replace('post-format-', '', $preston_post_format);
$preston_animation = preston_get_theme_option('blog_animation');
$preston_full_content = preston_get_theme_option('blog_content') != 'excerpt' || in_array($preston_post_format, array('link', 'aside', 'status', 'quote'));

?><div class="column-1_<?php echo esc_attr($preston_columns); ?>"><article id="post-<?php the_ID(); ?>" 
	<?php post_class( 'post_item post_layout_sticky post_format_'.esc_attr($preston_post_format) ); ?>
	<?php echo (!preston_is_off($preston_animation) ? ' data-animation="'.esc_attr(preston_get_animation_classes($preston_animation)).'"' : ''); ?>
	>

	<?php
	if ( is_sticky() && is_home() && !is_paged() ) {
		?><span class="post_label label_sticky"></span><?php
	}

	// Featured image
	preston_show_post_featured(array(
		'thumb_size' => preston_get_thumb_size($preston_columns==1 ? 'big' : ($preston_columns==2 ? 'med' : 'avatar'))
	));

	if ( !in_array($preston_post_format, array('link', 'aside', 'status', 'quote')) ) {
		?>
		<div class="post_header entry-header">
			<?php
			// Post title
			the_title( sprintf( '<h2 class="post_title entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h2>' );
            // Post meta
            preston_show_post_meta(array(
                    'categories' => false,
                    'author' => false,
                    'date' => true,
                    'edit' => false,
                    'seo' => false,
                    'share' => false,
                    'counters' => ''
                )
            );
			?>
		</div><!-- .entry-header -->
		<?php
        // Post content
        ?><div class="post_content entry-content"><?php
            if ($preston_full_content) {
                // Post content area
                ?><div class="post_content_inner"><?php
                the_content( '' );
                ?></div><?php
                // Inner pages
                wp_link_pages( array(
                    'before'      => '<div class="page_links"><span class="page_links_title">' . esc_html__( 'Pages:', 'preston' ) . '</span>',
                    'after'       => '</div>',
                    'link_before' => '<span>',
                    'link_after'  => '</span>',
                    'pagelink'    => '<span class="screen-reader-text">' . esc_html__( 'Page', 'preston' ) . ' </span>%',
                    'separator'   => '<span class="screen-reader-text">, </span>',
                ) );

            } else {

                $preston_show_learn_more = !in_array($preston_post_format, array('link', 'aside', 'status', 'quote'));

                // Post content area
                ?><div class="post_content_inner"><?php
                if (has_excerpt()) {
                    the_excerpt();
                } else if (strpos(get_the_content('!--more'), '!--more')!==false) {
                    the_content( '' );
                } else if (in_array($preston_post_format, array('link', 'aside', 'status', 'quote'))) {
                    the_content();
                } else if (substr(get_the_content(), 0, 1)!='[') {
                    the_excerpt();
                }
                ?></div><?php

                do_action('preston_action_before_post_meta');

                // Post meta
                preston_show_post_meta(array(
                        'categories' => false,
                        'author' => true,
                        'date' => false,
                        'edit' => false,
                        'seo' => false,
                        'share' => false,
                        'counters' => 'views,comments'
                    )
                );

            }
            ?></div><?php
	}
	?>
</article></div>