<?php
/**
 * The default template for displaying content of the single post, page or attachment
 *
 * Used for index/archive/search.
 *
 * @package WordPress
 * @subpackage PRESTON
 * @since PRESTON 1.0
 */
?>

<article id="post-<?php the_ID(); ?>" <?php post_class( 'post_item_single post_type_'.esc_attr(get_post_type()) 
												. ' post_format_'.esc_attr(str_replace('post-format-', '', get_post_format())) 
												. ' itemscope'
												); ?>
		itemscope itemtype="//schema.org/<?php echo esc_attr(is_single() ? 'BlogPosting' : 'Article'); ?>">
	<?php
	// Structured data snippets
	if (preston_is_on(preston_get_theme_option('seo_snippets'))) {
		?>
		<div class="structured_data_snippets">
			<meta itemprop="headline" content="<?php the_title_attribute(); ?>">
			<meta itemprop="datePublished" content="<?php echo esc_attr(get_the_date('Y-m-d')); ?>">
			<meta itemprop="dateModified" content="<?php echo esc_attr(get_the_modified_date('Y-m-d')); ?>">
			<meta itemscope itemprop="mainEntityOfPage" itemType="//schema.org/WebPage" itemid="<?php echo esc_url(get_the_permalink()); ?>" content="<?php the_title_attribute(); ?>"/>	
			<div itemprop="publisher" itemscope itemtype="//schema.org/Organization">
				<div itemprop="logo" itemscope itemtype="//schema.org/ImageObject">
					<?php 
					$preston_logo_image = preston_get_retina_multiplier(2) > 1 
										? preston_get_theme_option( 'logo_retina' )
										: preston_get_theme_option( 'logo' );
					if (!empty($preston_logo_image)) {
						$preston_attr = preston_getimagesize($preston_logo_image);
						?>
						<img itemprop="url" src="<?php echo esc_url($preston_logo_image); ?>">
						<meta itemprop="width" content="<?php echo esc_attr($preston_attr[0]); ?>">
						<meta itemprop="height" content="<?php echo esc_attr($preston_attr[1]); ?>">
						<?php
					}
					?>
				</div>
				<meta itemprop="name" content="<?php echo esc_attr(get_bloginfo( 'name' )); ?>">
				<meta itemprop="telephone" content="">
				<meta itemprop="address" content="">
			</div>
		</div>
		<?php
	}
	?><div class="post-date-left"><?php
        $dt = apply_filters('preston_filter_get_post_date', preston_get_date('', 'j M Y'));
        $date = explode(' ', $dt);
        if (count($date) > 1) {
            echo '<span class="post-day">' . esc_html($date[0]) .'</span>';
            echo '<span class="post-month">' . esc_html($date[1]) . ' ' . esc_html($date[2]).'</span>';
        }

        // Share
        preston_show_share_links(array(
            'type' => 'block',
            'caption' => '',
            'before' => '<span class="post_meta_item post_share">',
            'after' => '</span>'
        ));
        
        ?></div><div class="post-content-right"><?php
	
	// Featured image
	if ( !get_query_var('preston_featured_showed', false) )
		preston_show_post_featured();

	// Post content
	?>
	<div class="post_content entry-content" itemprop="articleBody">
		<?php
			the_content( );

			wp_link_pages( array(
				'before'      => '<div class="page_links"><span class="page_links_title">' . esc_html__( 'Pages:', 'preston' ) . '</span>',
				'after'       => '</div>',
				'link_before' => '<span>',
				'link_after'  => '</span>',
				'pagelink'    => '<span class="screen-reader-text">' . esc_html__( 'Page', 'preston' ) . ' </span>%',
				'separator'   => '<span class="screen-reader-text">, </span>',
			) );

			// Taxonomies and share
			if ( is_single() && !is_attachment() ) {
				?>
                <div class="post_meta post_meta_single"><?php
                    // Post taxonomies
                    ?><div class="single-meta"><?php
                            if ( !is_attachment() && !is_page() ) {
                                $cats = get_post_type()=='post' ? get_the_category_list(', ') : apply_filters('preston_filter_get_post_categories', '');
                                if (!empty($cats)) {
                                    ?>
                                    <span class="post_meta_item post_categories"><?php preston_show_layout($cats); ?></span>
                                <?php
                                }
                            }
                        if( get_the_tags() ) {
                            // Post taxonomies
                            ?><span class="post_meta_item post_tags"><?php the_tags('', ', ', ''); ?></span>
                        <?php

                        }
                        ?> </div> <?php
					?>
				</div>
				<?php
			}
		?>
    </div></div><!-- .entry-content -->

	<?php
		// Author bio.
		if ( is_single() && !is_attachment() && get_the_author_meta( 'description' ) ) {
			get_template_part( 'templates/author-bio' );
		}
	?>
</article>
