<?php
/**
 * Theme functions: init, enqueue scripts and styles, include required files and widgets
 *
 * @package WordPress
 * @subpackage PRESTON
 * @since PRESTON 1.0
 */

// Return current site protocol
if (!function_exists('preston_get_protocol')) {
	function preston_get_protocol() {
		return is_ssl() ? 'https' : 'http';
	}
}

// Theme storage
$PRESTON_STORAGE = array(
	// Theme required plugin's slugs
	'required_plugins' => array(

		// Required plugins
		// DON'T COMMENT OR REMOVE NEXT LINES!
		'trx_addons',
		'trx_updater',
		// Recommended (supported) plugins
		// If plugin not need - comment (or remove) it
		'contact-form-7',
		'essential-grid',
		'js_composer',
		'mailchimp-for-wp',
		'revslider',
		'cooked',
		'vc-extensions-bundle',
		'woocommerce',
        'elegro-payment',
        'wp-gdpr-compliance'
		),

    // Theme-specific URLs (will be escaped in place of the output)
    'theme_pro_key' => 'env-axiom',
    'theme_demo_url' => '//preston.axiomthemes.com',
    'theme_doc_url'  => preston_get_protocol() . '://preston.axiomthemes.com/doc',

    'theme_video_url' => preston_get_protocol() . '://www.youtube.com/channel/UCBjqhuwKj3MfE3B6Hg2oA8Q',

    'theme_support_url'  => preston_get_protocol() . '://themerex.net/support/',
    'theme_download_url' => preston_get_protocol() . '://themeforest.net/item/preston-fruit-company-organic-farming/20792932'
);




//-------------------------------------------------------
//-- Theme init
//-------------------------------------------------------

// Theme init priorities:
// 1 - register filters to add/remove lists items in the Theme Options
// 2 - create Theme Options
// 3 - add/remove Theme Options elements
// 5 - load Theme Options
// 9 - register other filters (for installer, etc.)
//10 - standard Theme init procedures (not ordered)

if ( !function_exists('preston_theme_setup1') ) {
	add_action( 'after_setup_theme', 'preston_theme_setup1', 1 );
	function preston_theme_setup1() {
		// Set theme content width
		$GLOBALS['content_width'] = apply_filters( 'preston_filter_content_width', 1170 );
	}
}

if ( !function_exists('preston_theme_setup') ) {
	add_action( 'after_setup_theme', 'preston_theme_setup' );
	function preston_theme_setup() {

		// Add default posts and comments RSS feed links to head 
		add_theme_support( 'automatic-feed-links' );
		
		// Enable support for Post Thumbnails
		add_theme_support( 'post-thumbnails' );
		set_post_thumbnail_size(370, 0, false);
		
		// Add thumb sizes		
		$thumb_sizes = apply_filters('preston_filter_add_thumb_sizes', array(
			'preston-thumb-huge'		=> array(1170, 658, true),
			'preston-thumb-big' 		=> array( 740, 416, true),
			'preston-thumb-med' 		=> array( 370, 275, true),
            'preston-thumb-square' 		=> array( 370, 370, true),
			'preston-thumb-tiny' 		=> array(  100,  100, true),
			'preston-thumb-masonry-big' => array( 770,   0, false),		// Only downscale, not crop
			'preston-thumb-masonry'		=> array( 370,   0, false),		// Only downscale, not crop
			)
		);
		$mult = preston_get_theme_option('retina_ready', 1);
		if ($mult > 1) $GLOBALS['content_width'] = apply_filters( 'preston_filter_content_width', 1170*$mult);
		foreach ($thumb_sizes as $k=>$v) {
			// Add Original dimensions
			add_image_size( $k, $v[0], $v[1], $v[2]);
			// Add Retina dimensions
			if ($mult > 1) add_image_size( $k.'-@retina', $v[0]*$mult, $v[1]*$mult, $v[2]);
		}
		
		// Custom header setup
		add_theme_support( 'custom-header', array(
			'header-text'=>false
			)
		);

		// Custom backgrounds setup
		add_theme_support( 'custom-background', array()	);
		
		// Supported posts formats
		add_theme_support( 'post-formats', array('gallery', 'video', 'audio', 'link', 'quote', 'image', 'status', 'aside', 'chat') ); 
 
 		// Autogenerate title tag
		add_theme_support('title-tag');
 		
		// Add theme menus
		add_theme_support('nav-menus');
		
		// Switch default markup for search form, comment form, and comments to output valid HTML5.
		add_theme_support( 'html5', array('search-form', 'comment-form', 'comment-list', 'gallery', 'caption') );
		
		// WooCommerce Support
		add_theme_support( 'woocommerce' );
		
		// Editor custom stylesheet - for user
		add_editor_style( array_merge(
			array(
				'css/editor-style.css',
				preston_get_file_url('css/fontello/css/fontello-embedded.css')
			),
			preston_theme_fonts_for_editor()
			)
		);	
		
		// Make theme available for translation
		// Translations can be filed in the /languages/ directory
		load_theme_textdomain( 'preston', preston_get_folder_dir('languages') );
	
		// Register navigation menu
		register_nav_menus(array(
			'menu_main' => esc_html__('Main Menu', 'preston'),
			'menu_footer' => esc_html__('Footer Menu', 'preston')
			)
		);

		// Excerpt filters
		add_filter( 'excerpt_length',						'preston_excerpt_length' );
		add_filter( 'excerpt_more',							'preston_excerpt_more' );
		
		// Add required meta tags in the head
		add_action('wp_head',		 						'preston_wp_head', 1);
		
		// Add custom inline styles
		add_action('wp_footer',		 						'preston_wp_footer');
		add_action('admin_footer',	 						'preston_wp_footer');

		// Enqueue scripts and styles for frontend
		add_action('wp_enqueue_scripts', 					'preston_wp_scripts', 1000);			
		add_action('wp_footer',		 						'preston_localize_scripts');
		add_action('wp_enqueue_scripts', 					'preston_wp_scripts_responsive', 2000);	
		
		// Add body classes
		add_filter( 'body_class',							'preston_add_body_classes' );

		// Register sidebars
		add_action('widgets_init', 							'preston_widgets_init');
	}

}


//-------------------------------------------------------
//-- Thumb sizes
//-------------------------------------------------------
if ( !function_exists('preston_image_sizes') ) {
	add_filter( 'image_size_names_choose', 'preston_image_sizes' );
	function preston_image_sizes( $sizes ) {
		$thumb_sizes = apply_filters('preston_filter_add_thumb_sizes', array(
			'preston-thumb-huge'		=> esc_html__( 'Fullsize image', 'preston' ),
			'preston-thumb-big'			=> esc_html__( 'Large image', 'preston' ),
			'preston-thumb-med'			=> esc_html__( 'Medium image', 'preston' ),
			'preston-thumb-tiny'		=> esc_html__( 'Small square avatar', 'preston' ),
			'preston-thumb-masonry-big'	=> esc_html__( 'Masonry Large (scaled)', 'preston' ),
			'preston-thumb-masonry'		=> esc_html__( 'Masonry (scaled)', 'preston' ),
			)
		);
		$mult = preston_get_theme_option('retina_ready', 1);
		foreach($thumb_sizes as $k=>$v) {
			$sizes[$k] = $v;
			if ($mult > 1) $sizes[$k.'-@retina'] = $v.' '.esc_html__('@2x', 'preston' );
		}
		return $sizes;
	}
}


//-------------------------------------------------------
//-- Theme scripts and styles
//-------------------------------------------------------

// Load frontend scripts
if ( !function_exists( 'preston_wp_scripts' ) ) {
	function preston_wp_scripts() {
		
		// Enqueue styles
		//------------------------
		
		// Links to selected fonts
		$links = preston_theme_fonts_links();
		if (count($links) > 0) {
			foreach ($links as $slug => $link) {
				wp_enqueue_style( sprintf('preston-font-%s', $slug), $link );
			}
		}
		
		// Fontello styles must be loaded before main stylesheet
		// This style NEED the theme prefix, because style 'fontello' in some plugin contain different set of characters
		// and can't be used instead this style!
		wp_enqueue_style( 'fontello-style',  preston_get_file_url('css/fontello/css/fontello-embedded.css') );

		// Load main stylesheet
		$main_stylesheet = get_template_directory_uri() . '/style.css';
		wp_enqueue_style( 'preston-main', $main_stylesheet, array(), null );

		// Load child stylesheet (if different) after the main stylesheet and fontello icons (important!)
		$child_stylesheet = get_stylesheet_directory_uri() . '/style.css';
		if ($child_stylesheet != $main_stylesheet) {
			wp_enqueue_style( 'preston-child', $child_stylesheet, array('preston-main'), null );
		}
		
		// Animations
		if ( (preston_get_theme_option('blog_animation')!='none' || preston_get_theme_option('menu_animation_in')!='none' || preston_get_theme_option('menu_animation_out')!='none') && (preston_get_theme_option('animation_on_mobile')=='yes' || !wp_is_mobile()) && (!function_exists('preston_vc_is_frontend') || !preston_vc_is_frontend()))
			wp_enqueue_style( 'preston-animation',	preston_get_file_url('css/animation.css') );

		// Custom colors
		if ( !is_customize_preview() && !isset($_GET['color_scheme']) && preston_is_off(preston_get_theme_option('debug_mode')) )
			wp_enqueue_style( 'preston-colors', preston_get_file_url('css/__colors.css') );
		else
			wp_add_inline_style( 'preston-main', preston_customizer_get_css() );

		// Merged styles
		if ( preston_is_off(preston_get_theme_option('debug_mode')) )
			wp_enqueue_style( 'preston-styles', preston_get_file_url('css/__styles.css') );

		// Add post nav background
		preston_add_bg_in_post_nav();

		// Disable loading JQuery UI CSS
		wp_deregister_style('jquery_ui');
		wp_deregister_style('date-picker-css');


		// Enqueue scripts	
		//------------------------
		
		// Modernizr will load in head before other scripts and styles
		if ( substr(preston_get_theme_option('blog_style'), 0, 7) == 'gallery' || substr(preston_get_theme_option('blog_style'), 0, 9) == 'portfolio' )
			wp_enqueue_script( 'modernizr', preston_get_file_url('js/theme.gallery/modernizr.min.js'), array(), null, true );
		
		// Merged scripts
		if ( preston_is_off(preston_get_theme_option('debug_mode')) )
			wp_enqueue_script( 'preston-init', preston_get_file_url('js/__scripts.js'), array('jquery'), null, true );
		else {
			// Skip link focus
			wp_enqueue_script( 'skip-link-focus-fix', preston_get_file_url('js/skip-link-focus-fix.js'), null, true );
			// Superfish Menu
			wp_enqueue_script( 'superfish', preston_get_file_url('js/superfish.js'), array('jquery'), null, true );
			// Background video
			$header_video = preston_get_theme_option('header_video');
			if (!empty($header_video) && !preston_is_inherit($header_video))
				wp_enqueue_script( 'bideo', preston_get_file_url('js/bideo.js'), array(), null, true );
			// Theme scripts
			wp_enqueue_script( 'preston-utils', preston_get_file_url('js/_utils.js'), array('jquery'), null, true );
			wp_enqueue_script( 'preston-init', preston_get_file_url('js/_init.js'), array('jquery'), null, true );	
		}
		
		// Comments
		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}

		// Media elements library	
		if (preston_get_theme_setting('use_mediaelements')) {
			wp_enqueue_style ( 'mediaelement' );
			wp_enqueue_style ( 'wp-mediaelement' );
			wp_enqueue_script( 'mediaelement' );
			wp_enqueue_script( 'wp-mediaelement' );
		}
	}
}

// Add variables to the scripts in the frontend
if ( !function_exists( 'preston_localize_scripts' ) ) {
	function preston_localize_scripts() {
		wp_localize_script( 'preston-init', 'PRESTON_STORAGE', apply_filters( 'preston_filter_localize_script', array(
			// AJAX parameters
			'ajax_url' => esc_url(admin_url('admin-ajax.php')),
			'ajax_nonce' => esc_attr(wp_create_nonce(admin_url('admin-ajax.php'))),
			
			// Site base url
			'site_url' => get_site_url(),
			
			// User logged in
			'user_logged_in' => is_user_logged_in() ? true : false,
			
			// Menu width for mobile mode
			'mobile_layout_width' => max(480, preston_get_theme_option('mobile_layout_width')),

			// Stretch sidemenu to window height
			'menu_stretch' => preston_is_on(preston_get_theme_option('menu_stretch')),

			// Menu animation
			'menu_animation_in' => preston_get_theme_option('menu_animation_in'),
            'menu_animation_out' => preston_get_theme_option('menu_animation_out'),

			// Video background
			'background_video' => preston_get_theme_option('header_video'),

			// Video and Audio tag wrapper
			'use_mediaelements' => preston_get_theme_setting('use_mediaelements') ? true : false,

			// Messages max length
			'message_maxlength'	=> intval(preston_get_theme_setting('message_maxlength')),
						
			// Site color scheme
			'site_scheme' => sprintf('scheme_%s', preston_get_theme_option('color_scheme')),

			
			// Internal vars - do not change it!
			
			// Flag for review mechanism
			'admin_mode' => false,

			// E-mail mask
			'email_mask' => '^([a-zA-Z0-9_\\-]+\\.)*[a-zA-Z0-9_\\-]+@[a-z0-9_\\-]+(\\.[a-z0-9_\\-]+)*\\.[a-z]{2,6}$',
			
			// Strings for translation
			'strings' => array(
					'ajax_error'		=> esc_html__('Invalid server answer!', 'preston'),
					'error_global'		=> esc_html__('Error data validation!', 'preston'),
					'name_empty' 		=> esc_html__("The name can't be empty", 'preston'),
					'name_long'			=> esc_html__('Too long name', 'preston'),
					'email_empty'		=> esc_html__('Too short (or empty) email address', 'preston'),
					'email_long'		=> esc_html__('Too long email address', 'preston'),
					'email_not_valid'	=> esc_html__('Invalid email address', 'preston'),
					'text_empty'		=> esc_html__("The message text can't be empty", 'preston'),
					'text_long'			=> esc_html__('Too long message text', 'preston'),
					'search_error'		=> esc_html__('Search error! Try again later.', 'preston'),
					'send_complete'		=> esc_html__("Send message complete!", 'preston'),
					'send_error'		=> esc_html__('Transmit failed!', 'preston')
					)
			))
		);
	}
}

// Load responsive styles (priority 2000 - load it after main styles and plugins custom styles)
if ( !function_exists( 'preston_wp_scripts_responsive' ) ) {
	function preston_wp_scripts_responsive() {
		wp_enqueue_style( 'preston-responsive', preston_get_file_url('css/responsive.css') );
	}
}

//  Add meta tags and inline scripts in the header for frontend
if (!function_exists('preston_wp_head')) {
	function preston_wp_head() {
		?>
		<meta charset="<?php bloginfo( 'charset' ); ?>">
		<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
		<link rel="profile" href="//gmpg.org/xfn/11">
		<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">
		<?php
	}
}

// Add theme specified classes to the body
if ( !function_exists('preston_add_body_classes') ) {
	function preston_add_body_classes( $classes ) {
		$blog_mode = preston_storage_get('blog_mode');
		$classes[] = 'blog_mode_' . esc_attr($blog_mode);
		$classes[] = 'body_tag';
		$classes[] = 'body_style_' . esc_attr(preston_get_theme_option('body_style'));
		$classes[] = 'scheme_' . esc_attr(preston_get_theme_option('color_scheme'));
		if (in_array($blog_mode, array('post', 'page'))) {
			$classes[] = 'is_single';
		} else {
			$classes[] = ' is_stream';
			$classes[] = 'blog_style_'.esc_attr(preston_get_theme_option('blog_style'));
		}
		if (preston_sidebar_present()) {
			$classes[] = 'sidebar_show sidebar_' . esc_attr(preston_get_theme_option('sidebar_position')) ;
		} else {
			$classes[] = 'sidebar_hide';
			if (preston_is_on(preston_get_theme_option('expand_content')))
				 $classes[] = 'expand_content';
		}
		if (preston_is_on(preston_get_theme_option('remove_margins')))
			 $classes[] = 'remove_margins';

		$classes[] = 'header_style_' . esc_attr(preston_get_theme_option("header_style"));
		$classes[] = 'header_position_' . esc_attr(preston_get_theme_option("header_position"));
		$classes[] = 'header_title_' . esc_attr(preston_need_page_title() ? 'on' : 'off');

		$menu_style= preston_get_theme_option("menu_style");
		$classes[] = 'menu_style_' . esc_attr($menu_style) . (in_array($menu_style, array('left', 'right'))	? ' menu_style_side' : '');
		$classes[] = 'no_layout';
		
		return $classes;
	}
}
	
// Load inline styles
if ( !function_exists( 'preston_wp_footer' ) ) {
	function preston_wp_footer() {
		// Get inline styles from storage
		if (($css = preston_storage_get('inline_styles')) != '') {
			wp_enqueue_style(  'preston-inline-styles',  preston_get_file_url('css/__inline.css') );
			wp_add_inline_style( 'preston-inline-styles', $css );
		}
	}
}


//-------------------------------------------------------
//-- Sidebars and widgets
//-------------------------------------------------------

// Register widgetized areas
if ( !function_exists('preston_widgets_init') ) {	
	function preston_widgets_init() {
		$sidebars = preston_get_list_sidebars();
		if (is_array($sidebars) && count($sidebars) > 0) {
			foreach ($sidebars as $id=>$name) {
				register_sidebar( array(
										'name'          => $name,
										'id'            => $id,
										'before_widget' => '<aside id="%1$s" class="widget %2$s">',
										'after_widget'  => '</aside>',
										'before_title'  => '<h5 class="widget_title">',
										'after_title'   => '</h5>'
										)
								);
			}
		}
	}
}


//-------------------------------------------------------
//-- Theme fonts
//-------------------------------------------------------

// Return links for all theme fonts
if ( !function_exists('preston_theme_fonts_links') ) {
	function preston_theme_fonts_links() {
		$links = array();
		
		/*
		Translators: If there are characters in your language that are not supported
		by chosen font(s), translate this to 'off'. Do not translate into your own language.
		*/
		$google_fonts_enabled = ( 'off' !== esc_html_x( 'on', 'Google fonts: on or off', 'preston' ) );
		$custom_fonts_enabled = ( 'off' !== esc_html_x( 'on', 'Custom fonts (included in the theme): on or off', 'preston' ) );
		
		if ( ($google_fonts_enabled || $custom_fonts_enabled) && !preston_storage_empty('load_fonts') ) {
			$load_fonts = preston_storage_get('load_fonts');
			if (count($load_fonts) > 0) {
				$google_fonts = '';
				foreach ($load_fonts as $font) {
					$slug = preston_get_load_fonts_slug($font['name']);
					$url  = preston_get_file_url( sprintf('css/font-face/%s/stylesheet.css', $slug));
					if ($url != '') {
						if ($custom_fonts_enabled) {
							$links[$slug] = $url;
						}
					} else {
						if ($google_fonts_enabled) {
							$google_fonts .= ($google_fonts ? '%7C' : '')
											. str_replace(' ', '+', $font['name'])
											. ':' 
											. (empty($font['styles']) ? '400,400italic,700,700italic' : $font['styles']);
						}
					}
				}
				if ($google_fonts && $google_fonts_enabled) {
					$links['google_fonts'] = sprintf('//fonts.googleapis.com/css?family=%s&subset=%s', $google_fonts, preston_get_theme_option('load_fonts_subset'));
				}
			}
		}
		return $links;
	}
}

// Return links for WP Editor
if ( !function_exists('preston_theme_fonts_for_editor') ) {
	function preston_theme_fonts_for_editor() {
		$links = array_values(preston_theme_fonts_links());
		if (is_array($links) && count($links) > 0) {
			for ($i=0; $i<count($links); $i++) {
				$links[$i] = str_replace(',', '%2C', $links[$i]);
			}
		}
		return $links;
	}
}


//-------------------------------------------------------
//-- The Excerpt
//-------------------------------------------------------
if ( !function_exists('preston_excerpt_length') ) {
	function preston_excerpt_length( $length ) {
		return max(1, preston_get_theme_setting('max_excerpt_length'));
	}
}

if ( !function_exists('preston_excerpt_more') ) {
	function preston_excerpt_more( $more ) {
		return '&hellip;';
	}
}



function preston_move_comment_field_to_bottom( $fields ) {
    $comment_field = $fields['comment'];
    unset( $fields['comment'] );
    $fields['comment'] = $comment_field;
    return $fields;
}

add_filter( 'comment_form_fields', 'preston_move_comment_field_to_bottom' );

/**
* Fire the wp_body_open action.
*
* Added for backwards compatibility to support pre 5.2.0 WordPress versions.
*/
if ( ! function_exists( 'wp_body_open' ) ) {
  function wp_body_open() {
     /**
      * Triggered after the opening <body> tag.
      */
     do_action('wp_body_open');
  }
}

//-------------------------------------------------------
//-- Include theme (or child) PHP-files
//-------------------------------------------------------

require_once trailingslashit( get_template_directory() ) . 'includes/utils.php';
require_once trailingslashit( get_template_directory() ) . 'includes/storage.php';
require_once trailingslashit( get_template_directory() ) . 'includes/lists.php';
require_once trailingslashit( get_template_directory() ) . 'includes/wp.php';

require_once trailingslashit( get_template_directory() ) . 'includes/theme.tags.php';
require_once trailingslashit( get_template_directory() ) . 'includes/theme.hovers/theme.hovers.php';

if (is_admin()) {
	require_once trailingslashit( get_template_directory() ) . 'includes/tgmpa/class-tgm-plugin-activation.php';
	require_once trailingslashit( get_template_directory() ) . 'includes/admin.php';
}

require_once trailingslashit( get_template_directory() ) . 'theme-options/theme.customizer.php';


require_once trailingslashit( get_template_directory() ) . 'theme-specific/shortcodes.php';
// Plugins support
if (is_array($PRESTON_STORAGE['required_plugins']) && count($PRESTON_STORAGE['required_plugins']) > 0) {
	foreach ($PRESTON_STORAGE['required_plugins'] as $plugin_slug) {
		$plugin_slug = preston_esc($plugin_slug);
		$plugin_path = trailingslashit( get_template_directory() ) . sprintf('plugins/%s/%s.php', $plugin_slug, $plugin_slug);
		if (file_exists($plugin_path)) { require_once $plugin_path; }
	}
}

function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581327555&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        ?>