<?php
/**
 * The template for homepage posts with "Portfolio" style
 *
 * @package WordPress
 * @subpackage PRESTON
 * @since PRESTON 1.0
 */

preston_storage_set('blog_archive', true);

// Load scripts for both 'Gallery' and 'Portfolio' layouts!
wp_enqueue_script( 'classie', preston_get_file_url('js/theme.gallery/classie.min.js'), array(), null, true );
wp_enqueue_script( 'imagesloaded', preston_get_file_url('js/theme.gallery/imagesloaded.min.js'), array(), null, true );
wp_enqueue_script( 'masonry', preston_get_file_url('js/theme.gallery/masonry.min.js'), array(), null, true );
wp_enqueue_script( 'preston-gallery-script', preston_get_file_url('js/theme.gallery/theme.gallery.js'), array(), null, true );

get_header(); 

if (have_posts()) {
    $preston_id = '';
    $preston_cat = '';
    $preston_taxonomy = '';
    $preston_post_type = '';
	echo get_query_var('blog_archive_start');

	$preston_stickies = is_home() ? get_option( 'sticky_posts' ) : false;
	$preston_sticky_out = is_array($preston_stickies) && count($preston_stickies) > 0 && get_query_var( 'paged' ) < 1;
	
	// Show filters
	$preston_show_filters = preston_get_theme_option('show_filters');
	$preston_tabs = array();
	if (!preston_is_off($preston_show_filters)) {
		$preston_cat = preston_get_theme_option('parent_cat');
		$preston_post_type = preston_get_theme_option('post_type');
		$preston_taxonomy = preston_get_post_type_taxonomy($preston_post_type);
		$preston_args = array(
			'type'			=> $preston_post_type,
			'child_of'		=> $preston_cat,
			'orderby'		=> 'name',
			'order'			=> 'ASC',
			'hide_empty'	=> 1,
			'hierarchical'	=> 0,
			'exclude'		=> '',
			'include'		=> '',
			'number'		=> '',
			'taxonomy'		=> $preston_taxonomy,
			'pad_counts'	=> false
		);
		$preston_portfolio_list = get_terms($preston_args);
		if (is_array($preston_portfolio_list) && count($preston_portfolio_list) > 0) {
			$preston_tabs[$preston_cat] = esc_html__('All', 'preston');
			foreach ($preston_portfolio_list as $preston_term) {
				if (isset($preston_term->term_id)) $preston_tabs[$preston_term->term_id] = $preston_term->name;
			}
		}
	}
	if (count($preston_tabs) > 0) {
		$preston_portfolio_filters_ajax = true;
		$preston_portfolio_filters_active = $preston_cat;
		$preston_portfolio_filters_id = 'portfolio_filters';
		if (!is_customize_preview())
			wp_enqueue_script('jquery-ui-tabs', false, array('jquery', 'jquery-ui-core'), null, true);
		?>
		<div class="portfolio_filters preston_tabs preston_tabs_ajax">
			<ul class="portfolio_titles preston_tabs_titles">
				<?php
				foreach ($preston_tabs as $preston_id=>$preston_title) {
					?><li><a href="<?php echo esc_url(preston_get_hash_link(sprintf('#%s_%s_content', $preston_portfolio_filters_id, $preston_id))); ?>" data-tab="<?php echo esc_attr($preston_id); ?>"><?php echo esc_html($preston_title); ?></a></li><?php
				}
				?>
			</ul>
			<?php
			$preston_ppp = preston_get_theme_option('posts_per_page');
			if (preston_is_inherit($preston_ppp)) $preston_ppp = '';
			foreach ($preston_tabs as $preston_id=>$preston_title) {
				$preston_portfolio_need_content = $preston_id==$preston_portfolio_filters_active || !$preston_portfolio_filters_ajax;
				?>
				<div id="<?php echo esc_attr(sprintf('%s_%s_content', $preston_portfolio_filters_id, $preston_id)); ?>"
					class="portfolio_content preston_tabs_content"
					data-blog-template="<?php echo esc_attr(preston_storage_get('blog_template')); ?>"
					data-blog-style="<?php echo esc_attr(preston_get_theme_option('blog_style')); ?>"
					data-posts-per-page="<?php echo esc_attr($preston_ppp); ?>"
					data-post-type="<?php echo esc_attr($preston_post_type); ?>"
					data-taxonomy="<?php echo esc_attr($preston_taxonomy); ?>"
					data-cat="<?php echo esc_attr($preston_id); ?>"
					data-parent-cat="<?php echo esc_attr($preston_cat); ?>"
					data-need-content="<?php echo (false===$preston_portfolio_need_content ? 'true' : 'false'); ?>"
				>
					<?php
					if ($preston_portfolio_need_content) 
						preston_show_portfolio_posts(array(
							'cat' => $preston_id,
							'parent_cat' => $preston_cat,
							'taxonomy' => $preston_taxonomy,
							'post_type' => $preston_post_type,
							'page' => 1,
							'sticky' => $preston_sticky_out
							)
						);
					?>
				</div>
				<?php
			}
			?>
		</div>
		<?php
	} else {
		preston_show_portfolio_posts(array(
			'cat' => $preston_id,
			'parent_cat' => $preston_cat,
			'taxonomy' => $preston_taxonomy,
			'post_type' => $preston_post_type,
			'page' => 1,
			'sticky' => $preston_sticky_out
			)
		);
	}

	echo get_query_var('blog_archive_end');

} else {

	if ( is_search() )
		get_template_part( 'content', 'none-search' );
	else
		get_template_part( 'content', 'none-archive' );

}

get_footer();
?>