<?php
/* Mail Chimp support functions
------------------------------------------------------------------------------- */

// Theme init priorities:
// 9 - register other filters (for installer, etc.)
if (!function_exists('preston_mailchimp_theme_setup9')) {
	add_action( 'after_setup_theme', 'preston_mailchimp_theme_setup9', 9 );
	function preston_mailchimp_theme_setup9() {
		if (preston_exists_mailchimp()) {
			add_action( 'wp_enqueue_scripts',							'preston_mailchimp_frontend_scripts', 1100 );
			add_filter( 'preston_filter_merge_styles',					'preston_mailchimp_merge_styles');
			add_filter( 'preston_filter_get_css',						'preston_mailchimp_get_css', 10, 3);
		}
		if (is_admin()) {
			add_filter( 'preston_filter_tgmpa_required_plugins',		'preston_mailchimp_tgmpa_required_plugins' );
		}
	}
}

// Check if plugin installed and activated
if ( !function_exists( 'preston_exists_mailchimp' ) ) {
	function preston_exists_mailchimp() {
		return function_exists('__mc4wp_load_plugin') || defined('MC4WP_VERSION');
	}
}

// Filter to add in the required plugins list
if ( !function_exists( 'preston_mailchimp_tgmpa_required_plugins' ) ) {
	function preston_mailchimp_tgmpa_required_plugins($list=array()) {
		if (in_array('mailchimp-for-wp', preston_storage_get('required_plugins')))
			$list[] = array(
				'name' 		=> esc_html__('MailChimp for WP', 'preston'),
				'slug' 		=> 'mailchimp-for-wp',
				'required' 	=> false
			);
		return $list;
	}
}



// Custom styles and scripts
//------------------------------------------------------------------------

// Enqueue custom styles
if ( !function_exists( 'preston_mailchimp_frontend_scripts' ) ) {
	function preston_mailchimp_frontend_scripts() {
		if (preston_exists_mailchimp()) {
			if (preston_is_on(preston_get_theme_option('debug_mode')) && file_exists(preston_get_file_dir('plugins/mailchimp-for-wp/mailchimp-for-wp.css')))
				wp_enqueue_style( 'preston-mailchimp-for-wp',  preston_get_file_url('plugins/mailchimp-for-wp/mailchimp-for-wp.css'), array(), null );
		}
	}
}
	
// Merge custom styles
if ( !function_exists( 'preston_mailchimp_merge_styles' ) ) {
	function preston_mailchimp_merge_styles($list) {
		$list[] = 'plugins/mailchimp-for-wp/mailchimp-for-wp.css';
		return $list;
	}
}

// Add css styles into global CSS stylesheet
if (!function_exists('preston_mailchimp_get_css')) {
	function preston_mailchimp_get_css($css, $colors, $fonts) {
		
		if (isset($css['fonts']) && $fonts) {
			$css['fonts'] .= <<<CSS

CSS;
		}
		
		if (isset($css['colors']) && $colors) {
			$css['colors'] .= <<<CSS

.mc4wp-form input[type="email"] {
	background-color: {$colors['input_bd_color']};
	border-color: {$colors['input_bd_color']};
	color: {$colors['bg_color']};
}
.mc4wp-form input[type="email"]::-webkit-input-placeholder{
    color: {$colors['bg_color']};
}
.widget_text .mc4wp-form button[type="submit"] {
	background-color: {$colors['alter_link']};
	color: {$colors['text_link']};
}
.widget_text .mc4wp-form button[type="submit"]:hover {
	background-color: {$colors['alter_dark']};
	color: {$colors['inverse_text']};
}

CSS;
		}

		return $css;
	}
}
?>