<?php
/**
 * Default Theme Options and Internal Theme Settings
 *
 * @package WordPress
 * @subpackage PRESTON
 * @since PRESTON 1.0
 */

// -----------------------------------------------------------------
// -- ONLY FOR PROGRAMMERS, NOT FOR CUSTOMER
// -- Internal theme settings
// -----------------------------------------------------------------
preston_storage_set('settings', array(
	
	'custom_sidebars'			=> 8,							// How many custom sidebars will be registered (in addition to theme preset sidebars): 0 - 10

	'ajax_views_counter'		=> true,						// Use AJAX for increment posts counter (if cache plugins used) 
																// or increment posts counter then loading page (without cache plugin)
	'disable_jquery_ui'			=> false,						// Prevent loading custom jQuery UI libraries in the third-party plugins

	'max_load_fonts'			=> 4,							// Max fonts number to load from Google fonts or from uploaded fonts

	'breadcrumbs_max_level' 	=> 3,							// Max number of the nested categories in the breadcrumbs (0 - unlimited)

	'use_mediaelements'			=> true,						// Load script "Media Elements" to play video and audio

	'max_excerpt_length'		=> 25,							// Max words number for the excerpt in the blog style 'Excerpt'.
																// For style 'Classic' - get half from this value
	'message_maxlength'			=> 1000							// Max length of the message from contact form
	
));



// -----------------------------------------------------------------
// -- Theme fonts (Google and/or custom fonts)
// -----------------------------------------------------------------

// Fonts to load when theme start
// It can be Google fonts or uploaded fonts, placed in the folder /css/font-face/font-name inside the theme folder
// Attention! Font's folder must have name equal to the font's name, with spaces replaced on the dash '-'

preston_storage_set('load_fonts', array(
	// Google font
	array(
		'name'	 => 'Trade Winds',
		'family' => 'cursive',
		'styles' => 'wght@400'		// Parameter 'style' used only for the Google fonts
		),
    // Google font
    array(
        'name'	 => 'Sacramento',
        'family' => 'cursive',
        'styles' => 'wght@400'		// Parameter 'style' used only for the Google fonts
    ),
    // Google font
    array(
        'name'	 => 'Neuton',
        'family' => 'serif',
        'styles' => 'wght@400;700'		// Parameter 'style' used only for the Google fonts
    ),
    // Google font
    array(
        'name'	 => 'Catamaran',
        'family' => 'serif',
        'styles' => 'wght@400;700'		// Parameter 'style' used only for the Google fonts
    )
));

// Characters subset for the Google fonts. Available values are: latin,latin-ext,cyrillic,cyrillic-ext,greek,greek-ext,vietnamese
preston_storage_set('load_fonts_subset', 'latin,latin-ext');

// Settings of the main tags
preston_storage_set('theme_fonts', array(
	'p' => array(
		'title'				=> esc_html__('Main text', 'preston'),
		'description'		=> esc_html__('Font settings of the main text of the site', 'preston'),
		'font-family'		=> '"Neuton",serif',
		'font-size' 		=> '1.2857rem',
		'font-weight'		=> '400',
		'font-style'		=> 'normal',
		'line-height'		=> '1.334em',
		'text-decoration'	=> 'none',
		'text-transform'	=> 'none',
		'letter-spacing'	=> '0px',
		'margin-top'		=> '0em',
        'margin-bottom'		=> '1.4em'
		),
	'h1' => array(
		'title'				=> esc_html__('Heading 1', 'preston'),
		'font-family'		=> '"Trade Winds", cursive',
		'font-size' 		=> '3.857rem',
		'font-weight'		=> '400',
		'font-style'		=> 'normal',
		'line-height'		=> '1.25em',
		'text-decoration'	=> 'none',
		'text-transform'	=> 'none',
		'letter-spacing'	=> '-0.8px',
		'margin-top'		=> '0.92em',
		'margin-bottom'		=> '0.35em'
		),
	'h2' => array(
		'title'				=> esc_html__('Heading 2', 'preston'),
		'font-family'		=> '"Trade Winds", cursive',
		'font-size' 		=> '3rem',
		'font-weight'		=> '400',
		'font-style'		=> 'normal',
		'line-height'		=> '1.1111em',
		'text-decoration'	=> 'none',
		'text-transform'	=> 'none',
		'letter-spacing'	=> '-0.3px',
		'margin-top'		=> '2.6em',
		'margin-bottom'		=> '0.45em'
		),
	'h3' => array(
		'title'				=> esc_html__('Heading 3', 'preston'),
		'font-family'		=> '"Neuton",serif',
		'font-size' 		=> '2.143rem',
		'font-weight'		=> '700',
		'font-style'		=> 'normal',
		'line-height'		=> '1.1515em',
		'text-decoration'	=> 'none',
		'text-transform'	=> 'uppercase',
		'letter-spacing'	=> '-0.1px',
		'margin-top'		=> '3.75em',
		'margin-bottom'		=> '0.81em'
		),
	'h4' => array(
		'title'				=> esc_html__('Heading 4', 'preston'),
		'font-family'		=> '"Trade Winds", cursive',
		'font-size' 		=> '1.714rem',
		'font-weight'		=> '400',
		'font-style'		=> 'normal',
		'line-height'		=> '1.3043em',
		'text-decoration'	=> 'none',
		'text-transform'	=> 'none',
		'letter-spacing'	=> '0px',
		'margin-top'		=> '4.77em',
		'margin-bottom'		=> '0.33em'
		),
	'h5' => array(
		'title'				=> esc_html__('Heading 5', 'preston'),
		'font-family'		=> '"Neuton",serif',
		'font-size' 		=> '1.286rem',
		'font-weight'		=> '700',
		'font-style'		=> 'normal',
		'line-height'		=> '1.35em',
		'text-decoration'	=> 'none',
		'text-transform'	=> 'uppercase',
		'letter-spacing'	=> '0',
		'margin-top'		=> '6.5em',
		'margin-bottom'		=> '0.75em'
		),
	'h6' => array(
		'title'				=> esc_html__('Heading 6', 'preston'),
		'font-family'		=> '"Neuton",serif',
		'font-size' 		=> '1rem',
		'font-weight'		=> '400',
		'font-style'		=> 'normal',
		'line-height'		=> '1.4706em',
		'text-decoration'	=> 'none',
		'text-transform'	=> 'uppercase',
		'letter-spacing'	=> '0.2px',
		'margin-top'		=> '8.4em',
		'margin-bottom'		=> '0.7em'
		),
	'logo' => array(
		'title'				=> esc_html__('Logo text', 'preston'),
		'description'		=> esc_html__('Font settings of the text case of the logo', 'preston'),
		'font-family'		=> '"Trade Winds", cursive',
		'font-size' 		=> '1.5em',
		'font-weight'		=> '400',
		'font-style'		=> 'normal',
		'line-height'		=> '1.25em',
		'text-decoration'	=> 'none',
		'text-transform'	=> 'uppercase',
		'letter-spacing'	=> '0px'
		),
	'button' => array(
		'title'				=> esc_html__('Buttons', 'preston'),
		'font-family'		=> '"Neuton", serif',
		'font-size' 		=> '1em',
		'font-weight'		=> '700',
		'font-style'		=> 'normal',
		'line-height'		=> '1.5em',
		'text-decoration'	=> 'none',
		'text-transform'	=> 'uppercase',
		'letter-spacing'	=> '0px'
		),
	'input' => array(
		'title'				=> esc_html__('Input felds', 'preston'),
		'description'		=> esc_html__('Font settings of the input fields, dropdowns and textareas', 'preston'),
		'font-family'		=> '"Neuton", serif',
		'font-size' 		=> '1em',
		'font-weight'		=> '400',
		'font-style'		=> 'normal',
		'line-height'		=> '1.2em',
		'text-decoration'	=> 'none',
		'text-transform'	=> 'none',
		'letter-spacing'	=> ''
		),
	'info' => array(
		'title'				=> esc_html__('Post meta', 'preston'),
		'description'		=> esc_html__('Font settings of the post meta: date, counters, share, etc.', 'preston'),
		'font-family'		=> '"Catamaran", sans-serif',
		'font-size' 		=> '12px',
		'font-weight'		=> '400',
		'font-style'		=> 'normal',
		'line-height'		=> '1.5em',
		'text-decoration'	=> 'none',
		'text-transform'	=> 'none',
		'letter-spacing'	=> '',
		'margin-top'		=> '1.6em',
		'margin-bottom'		=> ''
		),
	'menu' => array(
		'title'				=> esc_html__('Main menu', 'preston'),
		'description'		=> esc_html__('Font settings of the main menu items', 'preston'),
		'font-family'		=> '"Neuton",serif',
		'font-size' 		=> '1.286rem',
		'font-weight'		=> '400',
		'font-style'		=> 'normal',
		'line-height'		=> '1.5em',
		'text-decoration'	=> 'none',
		'text-transform'	=> 'none',
		'letter-spacing'	=> '0.4px'
		),
	'submenu' => array(
		'title'				=> esc_html__('Dropdown menu', 'preston'),
		'description'		=> esc_html__('Font settings of the dropdown menu items', 'preston'),
		'font-family'		=> '"Neuton",serif',
		'font-size' 		=> '1.286rem',
		'font-weight'		=> '400',
		'font-style'		=> 'normal',
		'line-height'		=> '1em',
		'text-decoration'	=> 'none',
		'text-transform'	=> 'none',
		'letter-spacing'	=> '0px'
		)
));


// -----------------------------------------------------------------
// -- Theme colors for customizer
// -- Attention! Inner scheme must be last in the array below
// -----------------------------------------------------------------
preston_storage_set('schemes', array(

	// Color scheme: 'default'
    'default' => array(
        'title'	 => esc_html__('Default', 'preston'),
        'colors' => array(

            // Whole block border and background
            'bg_color'				=> '#ffffff',
            'bd_color'				=> '#e7e3e1',    

            // Text and links colors
            'text'					=> '#9e8f84',    
            'text_light'			=> '#bac0c3',
            'text_dark'				=> '#55473d',    
            'text_link'				=> '#6eaa00',    
            'text_hover'			=> '#6eaa00',

            // Alternative blocks (submenu, buttons, tabs, etc.)
            'alter_bg_color'		=> '#876b5d',     
            'alter_bg_hover'		=> '#f0ecea',
            'alter_bd_color'		=> '#ddd3ce',       
            'alter_bd_hover'		=> '#ced5d9',
            'alter_text'			=> '#8b8582',      
            'alter_light'			=> '#817c79',      
            'alter_dark'			=> '#3c322b',      
            'alter_link'			=> '#927263',      
            'alter_hover'			=> '#33a1e3',

            // Input fields (form's fields and textarea)
            'input_bg_color'		=> '#f0edeb',   
            'input_bg_hover'		=> '#f0edeb',   
            'input_bd_color'		=> '#5d554f',       
            'input_bd_hover'		=> '#e5ecf1',
            'input_text'			=> '#7e7977',       
            'input_light'			=> '#b09a90',       
            'input_dark'			=> '#1e1d22',

            // Inverse blocks (text and links on accented bg)
            'inverse_text'			=> '#ffffff',     
            'inverse_light'			=> '#f7f7f7',
            'inverse_dark'			=> '#ffffff',
            'inverse_link'			=> '#ffffff',
            'inverse_hover'			=> '#13162b',

            // Additional accented colors (if used in the current theme)
            
            'accent2'				=> '#faef81'

        )
    ),

    // Color scheme: 'default'
    'dark' => array(
        'title'	 => esc_html__('Dark', 'preston'),
        'colors' => array(

            // Whole block border and background
            'bg_color'				=> '#ffffff',
            'bd_color'				=> '#e7e3e1',    

            // Text and links colors
            'text'					=> '#ffffff',    
            'text_light'			=> '#bac0c3',
            'text_dark'				=> '#ffffff',    
            'text_link'				=> '#6eaa00',    
            'text_hover'			=> '#33a1e3',

            // Alternative blocks (submenu, buttons, tabs, etc.)
            'alter_bg_color'		=> '#876b5d',     
            'alter_bg_hover'		=> '#f0ecea',
            'alter_bd_color'		=> '#dae1e5',
            'alter_bd_hover'		=> '#ced5d9',
            'alter_text'			=> '#8b8582',      
            'alter_light'			=> '#817c79',      
            'alter_dark'			=> '#3c322b',      
            'alter_link'			=> '#6eaa00',   
            'alter_hover'			=> '#33a1e3',

            // Input fields (form's fields and textarea)
            'input_bg_color'		=> '#f1f5f8',
            'input_bg_hover'		=> '#f1f5f8',
            'input_bd_color'		=> '#5d554f',       
            'input_bd_hover'		=> '#e5ecf1',
            'input_text'			=> '#bac0c3',
            'input_light'			=> '#b09a90',       
            'input_dark'			=> '#1e1d22',

            // Inverse blocks (text and links on accented bg)
            'inverse_text'			=> '#ffffff',     
            'inverse_light'			=> '#f7f7f7',
            'inverse_dark'			=> '#ffffff',
            'inverse_link'			=> '#ffffff',
            'inverse_hover'			=> '#13162b',

            // Additional accented colors (if used in the current theme)
            
            'accent2'				=> '#faef81'

        )
    ),

));



// -----------------------------------------------------------------
// -- Theme options for customizer
// -----------------------------------------------------------------
if (!function_exists('preston_options_create')) {

	function preston_options_create() {

		preston_storage_set('options', array(
		
			// Section 'Title & Tagline' - add theme options in the standard WP section
			'title_tagline' => array(
				"title" => esc_html__('Title, Tagline & Site icon', 'preston'),
				"desc" => wp_kses_data( __('Specify site title and tagline (if need) and upload the site icon', 'preston') ),
				"type" => "section"
				),
		
		
			// Section 'Header' - add theme options in the standard WP section
			'header_image' => array(
				"title" => esc_html__('Header', 'preston'),
				"desc" => wp_kses_data( __('Select or upload logo images, select header type and widgets set for the header', 'preston') ),
				"type" => "section"
				),
			'header_image_override' => array(
				"title" => esc_html__('Header image override', 'preston'),
				"desc" => wp_kses_data( __("Allow override the header image with the page's/post's/product's/etc. featured image", 'preston') ),
				"override" => array(
					'mode' => 'page, cpt_team',
					'section' => esc_html__('Header', 'preston')
				),
				"std" => 0,
				"type" => "checkbox"
				),
			'header_video' => array(
				"title" => esc_html__('Header video', 'preston'),
				"desc" => wp_kses_data( __("Select video to use it as background for the header", 'preston') ),
				"override" => array(
					'mode' => 'page, cpt_team',
					'section' => esc_html__('Header', 'preston')
				),
				"std" => '',
				"type" => "video"
				),
			'header_fullheight' => array(
				"title" => esc_html__('Fullheight Header', 'preston'),
				"desc" => wp_kses_data( __("Enlarge header area to fill whole screen. Used only if header have a background image", 'preston') ),
				"override" => array(
					'mode' => 'page, cpt_team',
					'section' => esc_html__('Header', 'preston')
				),
				"std" => 0,
				"type" => "checkbox"
				),
			'header_style' => array(
				"title" => esc_html__('Header style', 'preston'),
				"desc" => wp_kses_data( __('Select style to display the site header', 'preston') ),
				"override" => array(
					'mode' => 'page, cpt_team',
					'section' => esc_html__('Header', 'preston')
				),
				"std" => 'header-default',
				"options" => apply_filters('preston_filter_list_header_styles', array(
					'header-default' => esc_html__('Default Header',	'preston'),
                    'header-additional' => esc_html__('Additional Header',	'preston'),
				)),
				"type" => "select"
				),
			'header_position' => array(
				"title" => esc_html__('Header position', 'preston'),
				"desc" => wp_kses_data( __('Select position to display the site header', 'preston') ),
				"override" => array(
					'mode' => 'page, cpt_team',
					'section' => esc_html__('Header', 'preston')
				),
				"std" => 'default',
				"options" => array(
					'default' => esc_html__('Default','preston'),
					'over' => esc_html__('Over',	'preston'),
					'under' => esc_html__('Under',	'preston')
				),
				"type" => "select"
				),
			'header_scheme' => array(
				"title" => esc_html__('Header Color Scheme', 'preston'),
				"desc" => wp_kses_data( __('Select color scheme to decorate header area', 'preston') ),
				"override" => array(
					'mode' => 'page, cpt_team',
					'section' => esc_html__('Header', 'preston')
				),
				"std" => 'inherit',
				"options" => preston_get_list_schemes(true),
				"refresh" => false,
				"type" => "select"
				),
			'menu_style' => array(
				"title" => esc_html__('Menu position', 'preston'),
				"desc" => wp_kses_data( __('Select position of the main menu', 'preston') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Header', 'preston')
				),
				"std" => 'top',
				"options" => array(
					'top'	=> esc_html__('Top',	'preston'),
					'left'	=> esc_html__('Left',	'preston'),
					'right'	=> esc_html__('Right',	'preston')
				),
				"type" => "switch"
				),
			'menu_scheme' => array(
				"title" => esc_html__('Menu Color Scheme', 'preston'),
				"desc" => wp_kses_data( __('Select color scheme to decorate main menu area', 'preston') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Header', 'preston')
				),
				"std" => 'inherit',
				"options" => preston_get_list_schemes(true),
				"refresh" => false,
				"type" => "select"
				),
			'menu_stretch' => array(
				"title" => esc_html__('Stretch sidemenu', 'preston'),
				"desc" => wp_kses_data( __('Stretch sidemenu to window height (if menu items number >= 5)', 'preston') ),
				"std" => 1,
				"type" => "checkbox"
				),
			'search_style' => array(
				"title" => esc_html__('Search in the header', 'preston'),
				"desc" => wp_kses_data( __('Select style of the search field in the header', 'preston') ),
				"std" => 'expand',
				"options" => array(
					'expand' => esc_html__('Expand', 'preston'),
					'fullscreen' => esc_html__('Fullscreen', 'preston')
				),
				"type" => "switch"
				),
            'show_phone' => array(
                "title" => esc_html__('Show phone number in header', 'preston'),
                "desc" => wp_kses_data( __('Show phone number in header', 'preston') ),
                'refresh' => false,
                "override" => array(
                    'mode' => 'page',
                    'section' => esc_html__('Header', 'preston')
                ),
                "std" => 0,
                "type" => "checkbox"
            ),

            'phone_number' => array(
                "title" => esc_html__('Enter phone number', 'preston'),
                "desc" => wp_kses_data( __('Enter phone number', 'preston') ),
                "dependency" => array(
                    'show_phone' => array('1')
                ),
                "std" => '',
                "type" => "text"
            ),
            'show_address' => array(
                "title" => esc_html__('Show address in header', 'preston'),
                "desc" => wp_kses_data( __('Show address in header', 'preston') ),
                'refresh' => false,
                "override" => array(
                    'mode' => 'page',
                    'section' => esc_html__('Header', 'preston')
                ),
                "std" => 0,
                "type" => "checkbox"
            ),

            'address_text' => array(
                "title" => esc_html__('Enter address', 'preston'),
                "desc" => wp_kses_data( __('Enter address', 'preston') ),
                "dependency" => array(
                    'show_phone' => array('1')
                ),
                "std" => '',
                "type" => "text"
            ),


            'header_widgets' => array(
				"title" => esc_html__('Header widgets', 'preston'),
				"desc" => wp_kses_data( __('Select set of widgets to show in the header on each page', 'preston') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Header', 'preston'),
					"desc" => wp_kses_data( __('Select set of widgets to show in the header on this page', 'preston') ),
				),
				"std" => 'hide',
				"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'preston')), preston_get_list_sidebars()),
				"type" => "select"
				),
			'header_columns' => array(
				"title" => esc_html__('Header columns', 'preston'),
				"desc" => wp_kses_data( __('Select number columns to show widgets in the Header. If 0 - autodetect by the widgets count', 'preston') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Header', 'preston')
				),
				"dependency" => array(
					'header_widgets' => array('^hide')
				),
				"std" => 0,
				"options" => preston_get_list_range(0,6),
				"type" => "select"
				),
			'header_wide' => array(
				"title" => esc_html__('Header fullwide', 'preston'),
				"desc" => wp_kses_data( __('Do you want to stretch the header widgets area to the entire window width?', 'preston') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Header', 'preston')
				),
				"std" => 1,
				"type" => "checkbox"
				),
			'show_page_title' => array(
				"title" => esc_html__('Show Page Title', 'preston'),
				"desc" => wp_kses_data( __('Do you want to show page title area (page/post/category title and breadcrumbs)?', 'preston') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Header', 'preston')
				),
				"std" => 1,
				"type" => "checkbox"
				),
			'show_breadcrumbs' => array(
				"title" => esc_html__('Show breadcrumbs', 'preston'),
				"desc" => wp_kses_data( __('Do you want to show breadcrumbs in the page title area?', 'preston') ),
				"std" => 1,
				"type" => "checkbox"
				),
            'show_cart_header' => array(
                "title" => esc_html__('Show cart in header', 'preston'),
                "desc" => wp_kses_data( __('Do you want to show cart in header?', 'preston') ),
                'refresh' => true,
                "std" => 0,
                "type" => "checkbox"
            ),
			'logo' => array(
				"title" => esc_html__('Logo', 'preston'),
				"desc" => wp_kses_data( __('Select or upload site logo', 'preston') ),
				"std" => '',
				"type" => "image"
				),
			'logo_retina' => array(
				"title" => esc_html__('Logo for Retina', 'preston'),
				"desc" => wp_kses_data( __('Select or upload site logo used on Retina displays (if empty - use default logo from the field above)', 'preston') ),
				"std" => '',
				"type" => "image"
				),
			'header_title_image' => array(
				"title" => esc_html__('Header title image', 'preston'),
				"desc" => wp_kses_data( __('Select image to insert into the Header "Style 2"', 'preston') ),
				"std" => '',
				"type" => "hidden"
				),
			'header_title_text' => array(
				"title" => esc_html__('Header title text', 'preston'),
				"desc" => wp_kses_data( __('Put here text to insert into the Header "Style 2"', 'preston') ),
				"std" => '',
				"type" => "hidden"
				),
			'mobile_layout_width' => array(
				"title" => esc_html__('Mobile layout from', 'preston'),
				"desc" => wp_kses_data( __('Window width to show mobile layout of the header', 'preston') ),
				"std" => 959,
				"type" => "hidden"
				),
			
		
		
			// Section 'Content'
			'content' => array(
				"title" => esc_html__('Content', 'preston'),
				"desc" => wp_kses_data( __('Options for the content area', 'preston') ),
				"type" => "section",
				),
			'body_style' => array(
				"title" => esc_html__('Body style', 'preston'),
				"desc" => wp_kses_data( __('Select width of the body content', 'preston') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_courses',
					'section' => esc_html__('Content', 'preston')
				),
				"refresh" => false,
				"std" => 'wide',
				"options" => array(
					'boxed'		=> esc_html__('Boxed',		'preston'),
					'wide'		=> esc_html__('Wide',		'preston'),
					'fullwide'	=> esc_html__('Fullwide',	'preston'),
					'fullscreen'=> esc_html__('Fullscreen',	'preston')
				),
				"type" => "select"
				),
			'color_scheme' => array(
				"title" => esc_html__('Site Color Scheme', 'preston'),
				"desc" => wp_kses_data( __('Select color scheme to decorate whole site. Attention! Case "Inherit" can be used only for custom pages, not for root site content in the Appearance - Customize', 'preston') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Content', 'preston')
				),
				"std" => 'default',
				"options" => preston_get_list_schemes(true),
				"refresh" => false,
				"type" => "select"
				),
			'expand_content' => array(
				"title" => esc_html__('Expand content', 'preston'),
				"desc" => wp_kses_data( __('Expand the content width if the sidebar is hidden', 'preston') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_courses',
					'section' => esc_html__('Content', 'preston')
				),
				"refresh" => false,
				"std" => 1,
				"type" => "checkbox"
				),
			'remove_margins' => array(
				"title" => esc_html__('Remove margins', 'preston'),
				"desc" => wp_kses_data( __('Remove margins above and below the content area', 'preston') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_courses',
					'section' => esc_html__('Content', 'preston')
				),
				"refresh" => false,
				"std" => 0,
				"type" => "checkbox"
				),
			'seo_snippets' => array(
				"title" => esc_html__('SEO snippets', 'preston'),
				"desc" => wp_kses_data( __('Add structured data markup to the single posts and pages', 'preston') ),
				"std" => 0,
				"type" => "checkbox"
				),
            'privacy_text' => array(
                "title" => esc_html__("Text with Privacy Policy link", 'preston'),
                "desc"  => wp_kses_data( __("Specify text with Privacy Policy link for the checkbox 'I agree ...'", 'preston') ),
                "std"   => wp_kses( __( 'I agree that my submitted data is being collected and stored.', 'preston'), 'preston_kses_content' ),
                "type"  => "text"
            ),
			'no_image' => array(
				"title" => esc_html__('No image placeholder', 'preston'),
				"desc" => wp_kses_data( __('Select or upload image, used as placeholder for the posts without featured image', 'preston') ),
				"std" => '',
				"type" => "image"
				),
			'sidebar_widgets' => array(
				"title" => esc_html__('Sidebar widgets', 'preston'),
				"desc" => wp_kses_data( __('Select default widgets to show in the sidebar', 'preston') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_courses',
					'section' => esc_html__('Widgets', 'preston')
				),
				"std" => 'sidebar_widgets',
				"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'preston')), preston_get_list_sidebars()),
				"type" => "select"
				),
			'sidebar_scheme' => array(
				"title" => esc_html__('Color Scheme', 'preston'),
				"desc" => wp_kses_data( __('Select color scheme to decorate sidebar', 'preston') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_courses',
					'section' => esc_html__('Widgets', 'preston')
				),
				"std" => 'side',
				"options" => preston_get_list_schemes(true),
				"refresh" => false,
				"type" => "select"
				),
			'sidebar_position' => array(
				"title" => esc_html__('Sidebar position', 'preston'),
				"desc" => wp_kses_data( __('Select position to show sidebar', 'preston') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_courses',
					'section' => esc_html__('Widgets', 'preston')
				),
				"refresh" => false,
				"std" => 'right',
				"options" => preston_get_list_sidebars_positions(),
				"type" => "select"
				),
			'widgets_above_page' => array(
				"title" => esc_html__('Widgets above the page', 'preston'),
				"desc" => wp_kses_data( __('Select widgets to show above page (content and sidebar)', 'preston') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Widgets', 'preston')
				),
				"std" => 'hide',
				"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'preston')), preston_get_list_sidebars()),
				"type" => "select"
				),
			'widgets_above_content' => array(
				"title" => esc_html__('Widgets above the content', 'preston'),
				"desc" => wp_kses_data( __('Select widgets to show at the beginning of the content area', 'preston') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Widgets', 'preston')
				),
				"std" => 'hide',
				"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'preston')), preston_get_list_sidebars()),
				"type" => "select"
				),
			'widgets_below_content' => array(
				"title" => esc_html__('Widgets below the content', 'preston'),
				"desc" => wp_kses_data( __('Select widgets to show at the ending of the content area', 'preston') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Widgets', 'preston')
				),
				"std" => 'hide',
				"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'preston')), preston_get_list_sidebars()),
				"type" => "select"
				),
			'widgets_below_page' => array(
				"title" => esc_html__('Widgets below the page', 'preston'),
				"desc" => wp_kses_data( __('Select widgets to show below the page (content and sidebar)', 'preston') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Widgets', 'preston')
				),
				"std" => 'hide',
				"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'preston')), preston_get_list_sidebars()),
				"type" => "select"
				),
		
		
		
			// Section 'Footer'
			'footer' => array(
				"title" => esc_html__('Footer', 'preston'),
				"desc" => wp_kses_data( __('Select set of widgets and columns number for the site footer', 'preston') ),
				"type" => "section"
				),

            'footer_image' => array(
                "title" => esc_html__('Footer image', 'preston'),
                "desc" => wp_kses_data( __('Select image to insert into footer', 'preston') ),
                "std" => '',
                "type" => "image"
            ),

			'footer_scheme' => array(
				"title" => esc_html__('Footer Color Scheme', 'preston'),
				"desc" => wp_kses_data( __('Select color scheme to decorate footer area', 'preston') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_courses',
					'section' => esc_html__('Footer', 'preston')
				),
				"std" => 'dark',
				"options" => preston_get_list_schemes(true),
				"refresh" => false,
				"type" => "select"
				),
			'footer_widgets' => array(
				"title" => esc_html__('Footer widgets', 'preston'),
				"desc" => wp_kses_data( __('Select set of widgets to show in the footer', 'preston') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_courses',
					'section' => esc_html__('Footer', 'preston')
				),
				"std" => 'footer_widgets',
				"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'preston')), preston_get_list_sidebars()),
				"type" => "select"
				),
			'footer_columns' => array(
				"title" => esc_html__('Footer columns', 'preston'),
				"desc" => wp_kses_data( __('Select number columns to show widgets in the footer. If 0 - autodetect by the widgets count', 'preston') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_courses',
					'section' => esc_html__('Footer', 'preston')
				),
				"dependency" => array(
					'footer_widgets' => array('^hide')
				),
				"std" => 4,
				"options" => preston_get_list_range(0,6),
				"type" => "select"
				),
			'footer_wide' => array(
				"title" => esc_html__('Footer fullwide', 'preston'),
				"desc" => wp_kses_data( __('Do you want to stretch the footer to the entire window width?', 'preston') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_courses',
					'section' => esc_html__('Footer', 'preston')
				),
				"std" => 0,
				"type" => "checkbox"
				),
			'logo_in_footer' => array(
				"title" => esc_html__('Show logo', 'preston'),
				"desc" => wp_kses_data( __('Show logo in the footer', 'preston') ),
				'refresh' => false,
				"std" => 0,
				"type" => "checkbox"
				),
			'logo_footer' => array(
				"title" => esc_html__('Logo for footer', 'preston'),
				"desc" => wp_kses_data( __('Select or upload site logo to display it in the footer', 'preston') ),
				"dependency" => array(
					'logo_in_footer' => array('1')
				),
				"std" => '',
				"type" => "image"
				),
			'logo_footer_retina' => array(
				"title" => esc_html__('Logo for footer (Retina)', 'preston'),
				"desc" => wp_kses_data( __('Select or upload logo for the footer area used on Retina displays (if empty - use default logo from the field above)', 'preston') ),
				"dependency" => array(
					'logo_in_footer' => array('1')
				),
				"std" => '',
				"type" => "image"
				),
			'socials_in_footer' => array(
				"title" => esc_html__('Show social icons', 'preston'),
				"desc" => wp_kses_data( __('Show social icons in the footer (under logo or footer widgets)', 'preston') ),
				"std" => 0,
				"type" => "checkbox"
				),
			'copyright' => array(
				"title" => esc_html__('Copyright', 'preston'),
				"desc" => wp_kses_data( __('Copyright text in the footer', 'preston') ),
				"std" => esc_html__('Preston &copy; {Y}. All rights reserved. Terms of use and Privacy Policy', 'preston'),
				"refresh" => false,
				"type" => "textarea"
				),
		
		
		
			// Section 'Homepage' - settings for home page
			'homepage' => array(
				"title" => esc_html__('Homepage', 'preston'),
				"desc" => wp_kses_data( __('Select blog style and widgets to display on the homepage', 'preston') ),
				"type" => "section"
				),
			'expand_content_home' => array(
				"title" => esc_html__('Expand content', 'preston'),
				"desc" => wp_kses_data( __('Expand the content width if the sidebar is hidden on the Homepage', 'preston') ),
				"refresh" => false,
				"std" => 1,
				"type" => "checkbox"
				),
			'blog_style_home' => array(
				"title" => esc_html__('Blog style', 'preston'),
				"desc" => wp_kses_data( __('Select posts style for the homepage', 'preston') ),
				"std" => 'excerpt',
				"options" => preston_get_list_blog_styles(),
				"type" => "select"
				),
			'first_post_large_home' => array(
				"title" => esc_html__('First post large', 'preston'),
				"desc" => wp_kses_data( __('Make first post large (with Excerpt layout) on the Classic layout of the Homepage', 'preston') ),
				"dependency" => array(
					'blog_style_home' => array('classic')
				),
				"std" => 0,
				"type" => "checkbox"
				),
			'header_widgets_home' => array(
				"title" => esc_html__('Header widgets', 'preston'),
				"desc" => wp_kses_data( __('Select set of widgets to show in the header on the homepage', 'preston') ),
				"std" => 'header_widgets',
				"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'preston')), preston_get_list_sidebars()),
				"type" => "select"
				),
			'sidebar_widgets_home' => array(
				"title" => esc_html__('Sidebar widgets', 'preston'),
				"desc" => wp_kses_data( __('Select sidebar to show on the homepage', 'preston') ),
				"std" => 'sidebar_widgets',
				"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'preston')), preston_get_list_sidebars()),
				"type" => "select"
				),
			'sidebar_position_home' => array(
				"title" => esc_html__('Sidebar position', 'preston'),
				"desc" => wp_kses_data( __('Select position to show sidebar on the homepage', 'preston') ),
				"refresh" => false,
				"std" => 'right',
				"options" => preston_get_list_sidebars_positions(),
				"type" => "select"
				),
			'widgets_above_page_home' => array(
				"title" => esc_html__('Widgets above the page', 'preston'),
				"desc" => wp_kses_data( __('Select widgets to show above page (content and sidebar)', 'preston') ),
				"std" => 'hide',
				"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'preston')), preston_get_list_sidebars()),
				"type" => "select"
				),
			'widgets_above_content_home' => array(
				"title" => esc_html__('Widgets above the content', 'preston'),
				"desc" => wp_kses_data( __('Select widgets to show at the beginning of the content area', 'preston') ),
				"std" => 'hide',
				"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'preston')), preston_get_list_sidebars()),
				"type" => "select"
				),
			'widgets_below_content_home' => array(
				"title" => esc_html__('Widgets below the content', 'preston'),
				"desc" => wp_kses_data( __('Select widgets to show at the ending of the content area', 'preston') ),
				"std" => 'hide',
				"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'preston')), preston_get_list_sidebars()),
				"type" => "select"
				),
			'widgets_below_page_home' => array(
				"title" => esc_html__('Widgets below the page', 'preston'),
				"desc" => wp_kses_data( __('Select widgets to show below the page (content and sidebar)', 'preston') ),
				"std" => 'hide',
				"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'preston')), preston_get_list_sidebars()),
				"type" => "select"
				),
			
		
		
			// Section 'Blog archive'
			'blog' => array(
				"title" => esc_html__('Blog archive', 'preston'),
				"desc" => wp_kses_data( __('Options for the blog archive', 'preston') ),
				"type" => "section",
				),
			'expand_content_blog' => array(
				"title" => esc_html__('Expand content', 'preston'),
				"desc" => wp_kses_data( __('Expand the content width if the sidebar is hidden on the blog archive', 'preston') ),
				"refresh" => false,
				"std" => 1,
				"type" => "checkbox"
				),
			'blog_style' => array(
				"title" => esc_html__('Blog style', 'preston'),
				"desc" => wp_kses_data( __('Select posts style for the blog archive', 'preston') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Content', 'preston')
				),
				"dependency" => array(
                    '#page_template' => array( 'blog.php' ),
                    '.editor-page-attributes__template select' => array( 'blog.php' ),
				),
				"std" => 'excerpt',
				"options" => preston_get_list_blog_styles(),
				"type" => "select"
				),
			'blog_columns' => array(
				"title" => esc_html__('Blog columns', 'preston'),
				"desc" => wp_kses_data( __('How many columns should be used in the blog archive (from 2 to 4)?', 'preston') ),
				"std" => 2,
				"options" => preston_get_list_range(2,4),
				"type" => "hidden"
				),
			'post_type' => array(
				"title" => esc_html__('Post type', 'preston'),
				"desc" => wp_kses_data( __('Select post type to show in the blog archive', 'preston') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Content', 'preston')
				),
				"dependency" => array(
                    '#page_template' => array( 'blog.php' ),
                    '.editor-page-attributes__template select' => array( 'blog.php' ),
				),
				"linked" => 'parent_cat',
				"refresh" => false,
				"hidden" => true,
				"std" => 'post',
				"options" => preston_get_list_posts_types(),
				"type" => "select"
				),
			'parent_cat' => array(
				"title" => esc_html__('Category to show', 'preston'),
				"desc" => wp_kses_data( __('Select category to show in the blog archive', 'preston') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Content', 'preston')
				),
				"dependency" => array(
                    '#page_template' => array( 'blog.php' ),
                    '.editor-page-attributes__template select' => array( 'blog.php' ),
				),
				"refresh" => false,
				"hidden" => true,
				"std" => '0',
				"options" => preston_array_merge(array(0 => esc_html__('- Select category -', 'preston')), preston_get_list_categories()),
				"type" => "select"
				),
			'posts_per_page' => array(
				"title" => esc_html__('Posts per page', 'preston'),
				"desc" => wp_kses_data( __('How many posts will be displayed on this page', 'preston') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Content', 'preston')
				),
				"dependency" => array(
                    '#page_template' => array( 'blog.php' ),
                    '.editor-page-attributes__template select' => array( 'blog.php' ),
				),
				"hidden" => true,
				"std" => '10',
				"type" => "text"
				),
			"blog_pagination" => array( 
				"title" => esc_html__('Pagination style', 'preston'),
				"desc" => wp_kses_data( __('Show Older/Newest posts or Page numbers below the posts list', 'preston') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Content', 'preston')
				),
				"std" => "pages",
				"options" => array(
					'pages'	=> esc_html__("Page numbers", 'preston'),
					'links'	=> esc_html__("Older/Newest", 'preston'),
					'more'	=> esc_html__("Load more", 'preston'),
					'infinite' => esc_html__("Infinite scroll", 'preston')
				),
				"type" => "select"
				),
			'show_filters' => array(
				"title" => esc_html__('Show filters', 'preston'),
				"desc" => wp_kses_data( __('Show categories as tabs to filter posts', 'preston') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Content', 'preston')
				),
				"dependency" => array(
                    '#page_template' => array( 'blog.php' ),
                    '.editor-page-attributes__template select' => array( 'blog.php' ),
					'blog_style' => array('portfolio', 'gallery')
				),
				"hidden" => true,
				"std" => 0,
				"type" => "checkbox"
				),
			'first_post_large' => array(
				"title" => esc_html__('First post large', 'preston'),
				"desc" => wp_kses_data( __('Make first post large (with Excerpt layout) on the Classic layout of blog archive', 'preston') ),
				"dependency" => array(
					'blog_style' => array('classic')
				),
				"std" => 0,
				"type" => "checkbox"
				),
			"blog_content" => array( 
				"title" => esc_html__('Posts content', 'preston'),
				"desc" => wp_kses_data( __("Show full post's content in the blog or only post's excerpt", 'preston') ),
				"std" => "excerpt",
				"options" => array(
					'excerpt'	=> esc_html__('Excerpt',	'preston'),
					'fullpost'	=> esc_html__('Full post',	'preston')
				),
				"type" => "select"
				),
			'time_diff_before' => array(
				"title" => esc_html__('Time difference', 'preston'),
				"desc" => wp_kses_data( __("How many days show time difference instead post's date", 'preston') ),
				"std" => 5,
				"type" => "text"
				),
			'related_posts' => array(
				"title" => esc_html__('Related posts', 'preston'),
				"desc" => wp_kses_data( __('How many related posts should be displayed in the single post?', 'preston') ),
				"std" => 2,
				"options" => preston_get_list_range(0,4),
				"type" => "select"
				),
			"blog_animation" => array( 
				"title" => esc_html__('Animation for posts', 'preston'),
				"desc" => wp_kses_data( __('Select animation to show posts in the blog. Attention! Do not use any animation on pages with the "wheel to the anchor" behaviour (like a "Chess 2 columns")!', 'preston') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Content', 'preston')
				),
				"dependency" => array(
                    '#page_template' => array( 'blog.php' ),
                    '.editor-page-attributes__template select' => array( 'blog.php' ),
				),
				"std" => "none",
				"options" => preston_get_list_animations_in(),
				"type" => "select"
				),
			"animation_on_mobile" => array( 
				"title" => esc_html__('Allow animation on mobile', 'preston'),
				"desc" => wp_kses_data( __('Allow extended animation effects on mobile devices', 'preston') ),
				"std" => 'yes',
				"dependency" => array(
					'blog_animation' => array('^none')
				),
				"options" => preston_get_list_yesno(),
				"type" => "switch"
				),
			'header_widgets_blog' => array(
				"title" => esc_html__('Header widgets', 'preston'),
				"desc" => wp_kses_data( __('Select set of widgets to show in the header on the blog archive', 'preston') ),
				"std" => 'hide',
				"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'preston')), preston_get_list_sidebars()),
				"type" => "select"
				),
			'sidebar_widgets_blog' => array(
				"title" => esc_html__('Sidebar widgets', 'preston'),
				"desc" => wp_kses_data( __('Select sidebar to show on the blog archive', 'preston') ),
				"std" => 'sidebar_widgets',
				"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'preston')), preston_get_list_sidebars()),
				"type" => "select"
				),
			'sidebar_position_blog' => array(
				"title" => esc_html__('Sidebar position', 'preston'),
				"desc" => wp_kses_data( __('Select position to show sidebar on the blog archive', 'preston') ),
				"refresh" => false,
				"std" => 'right',
				"options" => preston_get_list_sidebars_positions(),
				"type" => "select"
				),
			'widgets_above_page_blog' => array(
				"title" => esc_html__('Widgets above the page', 'preston'),
				"desc" => wp_kses_data( __('Select widgets to show above page (content and sidebar)', 'preston') ),
				"std" => 'hide',
				"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'preston')), preston_get_list_sidebars()),
				"type" => "select"
				),
			'widgets_above_content_blog' => array(
				"title" => esc_html__('Widgets above the content', 'preston'),
				"desc" => wp_kses_data( __('Select widgets to show at the beginning of the content area', 'preston') ),
				"std" => 'hide',
				"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'preston')), preston_get_list_sidebars()),
				"type" => "select"
				),
			'widgets_below_content_blog' => array(
				"title" => esc_html__('Widgets below the content', 'preston'),
				"desc" => wp_kses_data( __('Select widgets to show at the ending of the content area', 'preston') ),
				"std" => 'hide',
				"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'preston')), preston_get_list_sidebars()),
				"type" => "select"
				),
			'widgets_below_page_blog' => array(
				"title" => esc_html__('Widgets below the page', 'preston'),
				"desc" => wp_kses_data( __('Select widgets to show below the page (content and sidebar)', 'preston') ),
				"std" => 'hide',
				"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'preston')), preston_get_list_sidebars()),
				"type" => "select"
				),
			
		
		
		
			// Section 'Colors' - choose color scheme and customize separate colors from it
			'scheme' => array(
				"title" => esc_html__('* Color scheme editor', 'preston'),
				"desc" => wp_kses_data( __("<b>Simple settings</b> - you can change only accented color, used for links, buttons and some accented areas.", 'preston') )
						. '<br>'
						. wp_kses_data( __("<b>Advanced settings</b> - change all scheme's colors and get full control over the appearance of your site!", 'preston') ),
				"priority" => 1000,
				"type" => "section"
				),
		
			'color_settings' => array(
				"title" => esc_html__('Color settings', 'preston'),
				"desc" => '',
				"std" => 'simple',
				"options" => array(
					"simple"  => esc_html__("Simple", 'preston'),
					"advanced" => esc_html__("Advanced", 'preston')
				),
				"refresh" => false,
				"type" => "switch"
				),
		
			'color_scheme_editor' => array(
				"title" => esc_html__('Color Scheme', 'preston'),
				"desc" => wp_kses_data( __('Select color scheme to edit colors', 'preston') ),
				"std" => 'default',
				"options" => preston_get_list_schemes(),
				"refresh" => false,
				"type" => "select"
				),
		
			'scheme_storage' => array(
				"title" => esc_html__('Colors storage', 'preston'),
				"desc" => esc_html__('Hidden storage of the all color from the all color shemes (only for internal usage)', 'preston'),
				"std" => '',
				"refresh" => false,
				"type" => "hidden"
				),
		
			'scheme_info_single' => array(
				"title" => esc_html__('Colors for single post/page', 'preston'),
				"desc" => wp_kses_data( __('Specify colors for single post/page (not for alter blocks)', 'preston') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"type" => "info"
				),
				
			'bg_color' => array(
				"title" => esc_html__('Background color', 'preston'),
				"desc" => wp_kses_data( __('Background color of the whole page', 'preston') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$preston_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'bd_color' => array(
				"title" => esc_html__('Border color', 'preston'),
				"desc" => wp_kses_data( __('Color of the bordered elements, separators, etc.', 'preston') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$preston_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
		
			'text' => array(
				"title" => esc_html__('Text', 'preston'),
				"desc" => wp_kses_data( __('Plain text color on single page/post', 'preston') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$preston_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'text_light' => array(
				"title" => esc_html__('Light text', 'preston'),
				"desc" => wp_kses_data( __('Color of the post meta: post date and author, comments number, etc.', 'preston') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$preston_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'text_dark' => array(
				"title" => esc_html__('Dark text', 'preston'),
				"desc" => wp_kses_data( __('Color of the headers, strong text, etc.', 'preston') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$preston_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'text_link' => array(
				"title" => esc_html__('Links', 'preston'),
				"desc" => wp_kses_data( __('Color of links and accented areas', 'preston') ),
				"std" => '$preston_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'text_hover' => array(
				"title" => esc_html__('Links hover', 'preston'),
				"desc" => wp_kses_data( __('Hover color for links and accented areas', 'preston') ),
				"std" => '$preston_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
		
			'scheme_info_alter' => array(
				"title" => esc_html__('Colors for alternative blocks', 'preston'),
				"desc" => wp_kses_data( __('Specify colors for alternative blocks - rectangular blocks with its own background color (posts in homepage, blog archive, search results, widgets on sidebar, footer, etc.)', 'preston') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"type" => "info"
				),
		
			'alter_bg_color' => array(
				"title" => esc_html__('Alter background color', 'preston'),
				"desc" => wp_kses_data( __('Background color of the alternative blocks', 'preston') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$preston_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'alter_bg_hover' => array(
				"title" => esc_html__('Alter hovered background color', 'preston'),
				"desc" => wp_kses_data( __('Background color for the hovered state of the alternative blocks', 'preston') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$preston_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'alter_bd_color' => array(
				"title" => esc_html__('Alternative border color', 'preston'),
				"desc" => wp_kses_data( __('Border color of the alternative blocks', 'preston') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$preston_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'alter_bd_hover' => array(
				"title" => esc_html__('Alternative hovered border color', 'preston'),
				"desc" => wp_kses_data( __('Border color for the hovered state of the alter blocks', 'preston') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$preston_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'alter_text' => array(
				"title" => esc_html__('Alter text', 'preston'),
				"desc" => wp_kses_data( __('Text color of the alternative blocks', 'preston') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$preston_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'alter_light' => array(
				"title" => esc_html__('Alter light', 'preston'),
				"desc" => wp_kses_data( __('Color of the info blocks inside block with alternative background', 'preston') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$preston_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'alter_dark' => array(
				"title" => esc_html__('Alter dark', 'preston'),
				"desc" => wp_kses_data( __('Color of the headers inside block with alternative background', 'preston') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$preston_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'alter_link' => array(
				"title" => esc_html__('Alter link', 'preston'),
				"desc" => wp_kses_data( __('Color of the links inside block with alternative background', 'preston') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$preston_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'alter_hover' => array(
				"title" => esc_html__('Alter hover', 'preston'),
				"desc" => wp_kses_data( __('Color of the hovered links inside block with alternative background', 'preston') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$preston_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
		
			'scheme_info_input' => array(
				"title" => esc_html__('Colors for the form fields', 'preston'),
				"desc" => wp_kses_data( __('Specify colors for the form fields and textareas', 'preston') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"type" => "info"
				),
		
			'input_bg_color' => array(
				"title" => esc_html__('Inactive background', 'preston'),
				"desc" => wp_kses_data( __('Background color of the inactive form fields', 'preston') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$preston_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'input_bg_hover' => array(
				"title" => esc_html__('Active background', 'preston'),
				"desc" => wp_kses_data( __('Background color of the focused form fields', 'preston') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$preston_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'input_bd_color' => array(
				"title" => esc_html__('Inactive border', 'preston'),
				"desc" => wp_kses_data( __('Color of the border in the inactive form fields', 'preston') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$preston_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'input_bd_hover' => array(
				"title" => esc_html__('Active border', 'preston'),
				"desc" => wp_kses_data( __('Color of the border in the focused form fields', 'preston') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$preston_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'input_text' => array(
				"title" => esc_html__('Inactive field', 'preston'),
				"desc" => wp_kses_data( __('Color of the text in the inactive fields', 'preston') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$preston_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'input_light' => array(
				"title" => esc_html__('Disabled field', 'preston'),
				"desc" => wp_kses_data( __('Color of the disabled field', 'preston') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$preston_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'input_dark' => array(
				"title" => esc_html__('Active field', 'preston'),
				"desc" => wp_kses_data( __('Color of the active field', 'preston') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$preston_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
		
			'scheme_info_inverse' => array(
				"title" => esc_html__('Colors for inverse blocks', 'preston'),
				"desc" => wp_kses_data( __('Specify colors for inverse blocks, rectangular blocks with background color equal to the links color or one of accented colors (if used in the current theme)', 'preston') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"type" => "info"
				),
		
			'inverse_text' => array(
				"title" => esc_html__('Inverse text', 'preston'),
				"desc" => wp_kses_data( __('Color of the text inside block with accented background', 'preston') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$preston_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'inverse_light' => array(
				"title" => esc_html__('Inverse light', 'preston'),
				"desc" => wp_kses_data( __('Color of the info blocks inside block with accented background', 'preston') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$preston_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'inverse_dark' => array(
				"title" => esc_html__('Inverse dark', 'preston'),
				"desc" => wp_kses_data( __('Color of the headers inside block with accented background', 'preston') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$preston_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'inverse_link' => array(
				"title" => esc_html__('Inverse link', 'preston'),
				"desc" => wp_kses_data( __('Color of the links inside block with accented background', 'preston') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$preston_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'inverse_hover' => array(
				"title" => esc_html__('Inverse hover', 'preston'),
				"desc" => wp_kses_data( __('Color of the hovered links inside block with accented background', 'preston') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$preston_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),

			'accent2' => array(
				"title" => esc_html__('Accent2', 'preston'),
				"desc" => wp_kses_data( __('Color of the custom accented areas', 'preston') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$preston_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),


			// Section 'Hidden'
			'media_title' => array(
				"title" => esc_html__('Media title', 'preston'),
				"desc" => wp_kses_data( __('Used as title for the audio and video item in this post', 'preston') ),
				"override" => array(
					'mode' => 'post',
					'section' => esc_html__('Title', 'preston')
				),
				"hidden" => true,
				"std" => '',
				"type" => "text"
				),
			'media_author' => array(
				"title" => esc_html__('Media author', 'preston'),
				"desc" => wp_kses_data( __('Used as author name for the audio and video item in this post', 'preston') ),
				"override" => array(
					'mode' => 'post',
					'section' => esc_html__('Title', 'preston')
				),
				"hidden" => true,
				"std" => '',
				"type" => "text"
				),


			// Internal options.
			// Attention! Don't change any options in the section below!
			'reset_options' => array(
				"title" => '',
				"desc" => '',
				"std" => '0',
				"type" => "hidden",
				),

		));


		// Prepare panel 'Fonts'
		$fonts = array(
		
			// Panel 'Fonts' - manage fonts loading and set parameters of the base theme elements
			'fonts' => array(
				"title" => esc_html__('* Fonts settings', 'preston'),
				"desc" => '',
				"priority" => 1500,
				"type" => "panel"
				),

			// Section 'Load_fonts'
			'load_fonts' => array(
				"title" => esc_html__('Load fonts', 'preston'),
				"desc" => wp_kses_data( __('Specify fonts to load when theme start. You can use them in the base theme elements: headers, text, menu, links, input fields, etc.', 'preston') )
						. '<br>'
						. wp_kses_data( __('<b>Attention!</b> Press "Refresh" button to reload preview area after the all fonts are changed', 'preston') ),
				"type" => "section"
				),
			'load_fonts_subset' => array(
				"title" => esc_html__('Google fonts subsets', 'preston'),
				"desc" => wp_kses_data( __('Specify comma separated list of the subsets which will be load from Google fonts', 'preston') )
						. '<br>'
						. wp_kses_data( __('Available subsets are: latin,latin-ext,cyrillic,cyrillic-ext,greek,greek-ext,vietnamese', 'preston') ),
				"refresh" => false,
				"std" => '$preston_get_load_fonts_subset',
				"type" => "text"
				)
		);

		for ($i=1; $i<=preston_get_theme_setting('max_load_fonts'); $i++) {
			$fonts["load_fonts-{$i}-info"] = array(
				"title" => esc_html(sprintf(__('Font %s', 'preston'), $i)),
				"desc" => '',
				"type" => "info",
				);
			$fonts["load_fonts-{$i}-name"] = array(
				"title" => esc_html__('Font name', 'preston'),
				"desc" => '',
				"refresh" => false,
				"std" => '$preston_get_load_fonts_option',
				"type" => "text"
				);
			$fonts["load_fonts-{$i}-family"] = array(
				"title" => esc_html__('Font family', 'preston'),
				"desc" => $i==1 
							? wp_kses_data( __('Select font family to use it if font above is not available', 'preston') )
							: '',
				"refresh" => false,
				"std" => '$preston_get_load_fonts_option',
				"options" => array(
					'inherit' => esc_html__("Inherit", 'preston'),
					'serif' => esc_html__('serif', 'preston'),
					'sans-serif' => esc_html__('sans-serif', 'preston'),
					'monospace' => esc_html__('monospace', 'preston'),
					'cursive' => esc_html__('cursive', 'preston'),
					'fantasy' => esc_html__('fantasy', 'preston')
				),
				"type" => "select"
				);
			$fonts["load_fonts-{$i}-styles"] = array(
				"title" => esc_html__('Font styles', 'preston'),
				"desc" => $i==1 
							? wp_kses_data( __('Font styles used only for the Google fonts. This is a comma separated list of the font weight and styles. For example: 400,400italic,700', 'preston') )
											. '<br>'
								. wp_kses_data( __('<b>Attention!</b> Each weight and style increase download size! Specify only used weights and styles.', 'preston') )
							: '',
				"refresh" => false,
				"std" => '$preston_get_load_fonts_option',
				"type" => "text"
				);
		}
		$fonts['load_fonts_end'] = array(
			"type" => "section_end"
			);

		// Sections with font's attributes for each theme element
		$theme_fonts = preston_get_theme_fonts();
		foreach ($theme_fonts as $tag=>$v) {
			$fonts["{$tag}_section"] = array(
				"title" => !empty($v['title']) 
								? $v['title'] 
								: esc_html(sprintf(__('%s settings', 'preston'), $tag)),
				"desc" => !empty($v['description']) 
								? $v['description'] 
								: wp_kses( sprintf(__('Font settings of the "%s" tag.', 'preston'), $tag), 'preston_kses_content' ),
				"type" => "section",
				);
	
			foreach ($v as $css_prop=>$css_value) {
				if (in_array($css_prop, array('title', 'description'))) continue;
				$options = '';
				$type = 'text';
				$title = ucfirst(str_replace('-', ' ', $css_prop));
				if ($css_prop == 'font-family') {
					$type = 'select';
					$options = preston_get_list_load_fonts(true);
				} else if ($css_prop == 'font-weight') {
					$type = 'select';
					$options = array(
						'inherit' => esc_html__("Inherit", 'preston'),
						'100' => esc_html__('100 (Light)', 'preston'), 
						'200' => esc_html__('200 (Light)', 'preston'), 
						'300' => esc_html__('300 (Thin)',  'preston'),
						'400' => esc_html__('400 (Normal)', 'preston'),
						'500' => esc_html__('500 (Semibold)', 'preston'),
						'600' => esc_html__('600 (Semibold)', 'preston'),
						'700' => esc_html__('700 (Bold)', 'preston'),
						'800' => esc_html__('800 (Black)', 'preston'),
						'900' => esc_html__('900 (Black)', 'preston')
					);
				} else if ($css_prop == 'font-style') {
					$type = 'select';
					$options = array(
						'inherit' => esc_html__("Inherit", 'preston'),
						'normal' => esc_html__('Normal', 'preston'), 
						'italic' => esc_html__('Italic', 'preston')
					);
				} else if ($css_prop == 'text-decoration') {
					$type = 'select';
					$options = array(
						'inherit' => esc_html__("Inherit", 'preston'),
						'none' => esc_html__('None', 'preston'), 
						'underline' => esc_html__('Underline', 'preston'),
						'overline' => esc_html__('Overline', 'preston'),
						'line-through' => esc_html__('Line-through', 'preston')
					);
				} else if ($css_prop == 'text-transform') {
					$type = 'select';
					$options = array(
						'inherit' => esc_html__("Inherit", 'preston'),
						'none' => esc_html__('None', 'preston'), 
						'uppercase' => esc_html__('Uppercase', 'preston'),
						'lowercase' => esc_html__('Lowercase', 'preston'),
						'capitalize' => esc_html__('Capitalize', 'preston')
					);
				}
				$fonts["{$tag}_{$css_prop}"] = array(
					"title" => $title,
					"desc" => '',
					"refresh" => false,
					"std" => '$preston_get_theme_fonts_option',
					"options" => $options,
					"type" => $type
				);
			}
			
			$fonts["{$tag}_section_end"] = array(
				"type" => "section_end"
				);
		}

		$fonts['fonts_end'] = array(
			"type" => "panel_end"
			);

		// Add fonts parameters into Theme Options
		preston_storage_merge_array('options', '', $fonts);
	}
}




// -----------------------------------------------------------------
// -- Create and manage Theme Options
// -----------------------------------------------------------------

// Theme init priorities:
// 2 - create Theme Options
if (!function_exists('preston_options_theme_setup2')) {
	add_action( 'after_setup_theme', 'preston_options_theme_setup2', 2 );
	function preston_options_theme_setup2() {
		preston_options_create();
	}
}

// Step 1: Load default settings and previously saved mods
if (!function_exists('preston_options_theme_setup5')) {
	add_action( 'after_setup_theme', 'preston_options_theme_setup5', 5 );
	function preston_options_theme_setup5() {
		preston_storage_set('options_reloaded', false);
		preston_load_theme_options();
	}
}

// Step 2: Load current theme customization mods
if (is_customize_preview()) {
	if (!function_exists('preston_load_custom_options')) {
		add_action( 'wp_loaded', 'preston_load_custom_options' );
		function preston_load_custom_options() {
			if (!preston_storage_get('options_reloaded')) {
				preston_storage_set('options_reloaded', true);
				preston_load_theme_options();
			}
		}
	}
}

// Load current values for each customizable option
if ( !function_exists('preston_load_theme_options') ) {
	function preston_load_theme_options() {
		$options = preston_storage_get('options');
		$reset = (int) get_theme_mod('reset_options', 0);
		foreach ($options as $k=>$v) {
			if (isset($v['std'])) {
				if (strpos($v['std'], '$preston_')!==false) {
					$func = substr($v['std'], 1);
					if (function_exists($func)) {
						$v['std'] = $func($k);
					}
				}
				$value = $v['std'];
				if (!$reset) {
					if (isset($_GET[$k]))
					$value = wp_kses_data( wp_unslash( $_GET[ $k ] ) );
				else {
						$tmp = get_theme_mod($k, -987654321);
						if ($tmp != -987654321) $value = $tmp;
					}
				}
				preston_storage_set_array2('options', $k, 'val', $value);
				if ($reset) remove_theme_mod($k);
			}
		}
		if ($reset) {
			// Unset reset flag
			set_theme_mod('reset_options', 0);
			// Regenerate CSS with default colors and fonts
			preston_customizer_save_css();
		} else {
			do_action('preston_action_load_options');
		}
	}
}

// Override options with stored page/post meta
if ( !function_exists('preston_override_theme_options') ) {
	add_action( 'wp', 'preston_override_theme_options', 1 );
	function preston_override_theme_options($query=null) {
		if (is_page_template('blog.php')) {
			preston_storage_set('blog_archive', true);
			preston_storage_set('blog_template', get_the_ID());
		}
		preston_storage_set('blog_mode', preston_detect_blog_mode());
		if (is_singular()) {
			preston_storage_set('options_meta', get_post_meta(get_the_ID(), 'preston_options', true));
		}
	}
}


// Return customizable option value
if (!function_exists('preston_get_theme_option')) {
	function preston_get_theme_option($name, $defa='', $strict_mode=false, $post_id=0) {
		$rez = $defa;
		$from_post_meta = false;
		if ($post_id > 0) {
			if (!preston_storage_isset('post_options_meta', $post_id))
				preston_storage_set_array('post_options_meta', $post_id, get_post_meta($post_id, 'preston_options', true));
			if (preston_storage_isset('post_options_meta', $post_id, $name)) {
				$tmp = preston_storage_get_array('post_options_meta', $post_id, $name);
				if (!preston_is_inherit($tmp)) {
					$rez = $tmp;
					$from_post_meta = true;
				}
			}
		}
		if (!$from_post_meta && preston_storage_isset('options')) {
			if ( !preston_storage_isset('options', $name) ) {
				$rez = $tmp = '_not_exists_';
				if (function_exists('trx_addons_get_option'))
					$rez = trx_addons_get_option($name, $tmp, false);
				if ($rez === $tmp) {
					if ($strict_mode) {
						$s = debug_backtrace();
						$s = array_shift($s);
						echo '<pre>' . sprintf(esc_html__('Undefined option "%s" called from:', 'preston'), $name);
						if (function_exists('dco')) dco($s);
						else print_r($s);
						echo '</pre>';
						wp_die();
					} else
						$rez = $defa;
				}
			} else {
				$blog_mode = preston_storage_get('blog_mode');
				// Override option from GET or POST for current blog mode
				if (!empty($blog_mode) && isset($_REQUEST[$name . '_' . $blog_mode])) {
					$rez = sanitize_text_field( $_REQUEST[$name . '_' . $blog_mode] );
				// Override option from GET
				} else if (isset($_REQUEST[$name])) {
					$rez = sanitize_text_field( $_REQUEST[$name] );
				// Override option from current page settings (if exists)
				} else if (preston_storage_isset('options_meta', $name) && !preston_is_inherit(preston_storage_get_array('options_meta', $name))) {
					$rez = preston_storage_get_array('options_meta', $name);
				// Override option from current blog mode settings: 'home', 'search', 'page', 'post', 'blog', etc. (if exists)
				} else if (!empty($blog_mode) && preston_storage_isset('options', $name . '_' . $blog_mode, 'val') && !preston_is_inherit(preston_storage_get_array('options', $name . '_' . $blog_mode, 'val'))) {
					$rez = preston_storage_get_array('options', $name . '_' . $blog_mode, 'val');
				// Get saved option value
				} else if (preston_storage_isset('options', $name, 'val')) {
					$rez = preston_storage_get_array('options', $name, 'val');
				// Get ThemeREX Addons option value
				} else if (function_exists('trx_addons_get_option')) {
					$rez = trx_addons_get_option($name, $defa, false);
				}
			}
		}
		return $rez;
	}
}


// Check if customizable option exists
if (!function_exists('preston_check_theme_option')) {
	function preston_check_theme_option($name) {
		return preston_storage_isset('options', $name);
	}
}

// Get dependencies list from the Theme Options
if ( !function_exists('preston_get_theme_dependencies') ) {
	function preston_get_theme_dependencies() {
		$options = preston_storage_get('options');
		$depends = array();
		foreach ($options as $k=>$v) {
			if (isset($v['dependency'])) 
				$depends[$k] = $v['dependency'];
		}
		return $depends;
	}
}

// Return internal theme setting value
if (!function_exists('preston_get_theme_setting')) {
	function preston_get_theme_setting($name) {
		return preston_storage_isset('settings', $name) ? preston_storage_get_array('settings', $name) : false;
	}
}


// Set theme setting
if ( !function_exists( 'preston_set_theme_setting' ) ) {
	function preston_set_theme_setting($option_name, $value) {
		if (preston_storage_isset('settings', $option_name))
			preston_storage_set_array('settings', $option_name, $value);
	}
}
?>